# Generated from pddl.g4 by ANTLR 4.7
# encoding: utf-8
from antlr4 import *
from io import StringIO
from typing.io import TextIO
import sys

def serializedATN():
    with StringIO() as buf:
        buf.write("\3\u608b\ua72a\u8133\ub9ed\u417c\u3be7\u7786\u5964\3s")
        buf.write("\u03b7\4\2\t\2\4\3\t\3\4\4\t\4\4\5\t\5\4\6\t\6\4\7\t\7")
        buf.write("\4\b\t\b\4\t\t\t\4\n\t\n\4\13\t\13\4\f\t\f\4\r\t\r\4\16")
        buf.write("\t\16\4\17\t\17\4\20\t\20\4\21\t\21\4\22\t\22\4\23\t\23")
        buf.write("\4\24\t\24\4\25\t\25\4\26\t\26\4\27\t\27\4\30\t\30\4\31")
        buf.write("\t\31\4\32\t\32\4\33\t\33\4\34\t\34\4\35\t\35\4\36\t\36")
        buf.write("\4\37\t\37\4 \t \4!\t!\4\"\t\"\4#\t#\4$\t$\4%\t%\4&\t")
        buf.write("&\4\'\t\'\4(\t(\4)\t)\4*\t*\4+\t+\4,\t,\4-\t-\4.\t.\4")
        buf.write("/\t/\4\60\t\60\4\61\t\61\4\62\t\62\4\63\t\63\4\64\t\64")
        buf.write("\4\65\t\65\4\66\t\66\4\67\t\67\48\t8\49\t9\4:\t:\4;\t")
        buf.write(";\4<\t<\4=\t=\4>\t>\4?\t?\4@\t@\4A\tA\4B\tB\4C\tC\4D\t")
        buf.write("D\4E\tE\4F\tF\4G\tG\4H\tH\4I\tI\4J\tJ\3\2\3\2\5\2\u0097")
        buf.write("\n\2\3\3\3\3\3\3\3\3\5\3\u009d\n\3\3\3\5\3\u00a0\n\3\3")
        buf.write("\3\5\3\u00a3\n\3\3\3\5\3\u00a6\n\3\3\3\5\3\u00a9\n\3\3")
        buf.write("\3\5\3\u00ac\n\3\3\3\7\3\u00af\n\3\f\3\16\3\u00b2\13\3")
        buf.write("\3\3\3\3\3\4\3\4\3\4\3\4\3\4\3\5\3\5\3\5\6\5\u00be\n\5")
        buf.write("\r\5\16\5\u00bf\3\5\3\5\3\6\3\6\3\6\3\6\3\6\3\7\7\7\u00ca")
        buf.write("\n\7\f\7\16\7\u00cd\13\7\3\7\6\7\u00d0\n\7\r\7\16\7\u00d1")
        buf.write("\3\7\7\7\u00d5\n\7\f\7\16\7\u00d8\13\7\5\7\u00da\n\7\3")
        buf.write("\b\6\b\u00dd\n\b\r\b\16\b\u00de\3\b\3\b\3\b\3\t\3\t\3")
        buf.write("\t\6\t\u00e7\n\t\r\t\16\t\u00e8\3\t\3\t\3\t\5\t\u00ee")
        buf.write("\n\t\3\n\3\n\3\13\3\13\3\13\3\13\3\13\3\f\6\f\u00f8\n")
        buf.write("\f\r\f\16\f\u00f9\3\f\3\f\5\f\u00fe\n\f\7\f\u0100\n\f")
        buf.write("\f\f\16\f\u0103\13\f\3\r\3\r\3\r\3\r\3\r\3\16\3\16\3\17")
        buf.write("\3\17\3\20\3\20\3\20\3\20\3\20\3\21\3\21\3\21\6\21\u0116")
        buf.write("\n\21\r\21\16\21\u0117\3\21\3\21\3\22\3\22\3\22\3\22\3")
        buf.write("\22\3\23\3\23\3\24\7\24\u0124\n\24\f\24\16\24\u0127\13")
        buf.write("\24\3\24\6\24\u012a\n\24\r\24\16\24\u012b\3\24\7\24\u012f")
        buf.write("\n\24\f\24\16\24\u0132\13\24\5\24\u0134\n\24\3\25\6\25")
        buf.write("\u0137\n\25\r\25\16\25\u0138\3\25\3\25\3\25\3\26\3\26")
        buf.write("\3\26\3\26\3\26\3\27\3\27\3\27\5\27\u0146\n\27\3\30\3")
        buf.write("\30\3\30\3\30\3\30\3\30\3\30\3\30\3\30\3\30\3\31\3\31")
        buf.write("\3\32\3\32\3\32\3\32\5\32\u0158\n\32\5\32\u015a\n\32\3")
        buf.write("\32\3\32\3\32\3\32\5\32\u0160\n\32\5\32\u0162\n\32\3\33")
        buf.write("\3\33\3\34\3\34\3\34\3\34\7\34\u016a\n\34\f\34\16\34\u016d")
        buf.write("\13\34\3\34\3\34\3\34\3\34\7\34\u0173\n\34\f\34\16\34")
        buf.write("\u0176\13\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3")
        buf.write("\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34")
        buf.write("\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\5\34")
        buf.write("\u0195\n\34\3\35\3\35\3\35\3\35\3\35\3\35\3\36\3\36\3")
        buf.write("\36\7\36\u01a0\n\36\f\36\16\36\u01a3\13\36\3\36\3\36\3")
        buf.write("\37\3\37\5\37\u01a9\n\37\3 \3 \3 \3 \3 \3 \3 \3 \3 \3")
        buf.write(" \3!\3!\3!\3!\3!\3!\5!\u01bb\n!\3!\3!\3!\3!\5!\u01c1\n")
        buf.write("!\3\"\3\"\3\"\3\"\7\"\u01c7\n\"\f\"\16\"\u01ca\13\"\3")
        buf.write("\"\3\"\3\"\3\"\3\"\3\"\3\"\3\"\3\"\5\"\u01d5\n\"\3#\3")
        buf.write("#\3#\3#\5#\u01db\n#\3#\3#\3#\5#\u01e0\n#\3$\3$\3$\3$\3")
        buf.write("$\3$\3$\3$\3$\3$\3$\3$\5$\u01ee\n$\3%\3%\3&\3&\3\'\3\'")
        buf.write("\3\'\3\'\3\'\3\'\3(\3(\3(\3(\3(\3(\3(\3(\3(\3(\3(\3(\3")
        buf.write("(\5(\u0207\n(\3)\3)\3*\3*\3*\7*\u020e\n*\f*\16*\u0211")
        buf.write("\13*\3*\3*\3*\5*\u0216\n*\3+\3+\3+\7+\u021b\n+\f+\16+")
        buf.write("\u021e\13+\3+\3+\5+\u0222\n+\3,\3,\3,\3,\3,\3,\3,\3,\3")
        buf.write(",\3,\3,\3,\3,\3,\3,\5,\u0233\n,\3-\3-\3-\3-\3-\3-\3-\3")
        buf.write("-\3-\3-\3-\3-\5-\u0241\n-\3.\3.\3.\7.\u0246\n.\f.\16.")
        buf.write("\u0249\13.\3.\3.\5.\u024d\n.\3/\3/\3\60\3\60\3\61\3\61")
        buf.write("\3\62\3\62\3\62\6\62\u0258\n\62\r\62\16\62\u0259\3\62")
        buf.write("\3\62\3\62\3\62\3\62\5\62\u0261\n\62\3\63\3\63\3\63\3")
        buf.write("\63\3\63\3\63\3\63\3\63\3\63\3\63\3\63\3\63\5\63\u026f")
        buf.write("\n\63\3\64\3\64\3\65\3\65\5\65\u0275\n\65\3\66\3\66\3")
        buf.write("\66\7\66\u027a\n\66\f\66\16\66\u027d\13\66\3\66\3\66\3")
        buf.write("\66\3\66\3\66\3\66\3\66\3\66\3\66\3\66\3\66\3\66\3\66")
        buf.write("\3\66\3\66\3\66\3\66\3\66\3\66\3\66\3\66\3\66\5\66\u0295")
        buf.write("\n\66\3\67\3\67\3\67\3\67\3\67\3\67\3\67\3\67\3\67\3\67")
        buf.write("\3\67\3\67\3\67\3\67\3\67\3\67\3\67\3\67\5\67\u02a9\n")
        buf.write("\67\38\38\38\38\38\38\39\39\39\39\39\39\39\59\u02b8\n")
        buf.write("9\39\39\39\39\59\u02be\n9\3:\3:\3;\3;\3;\3;\3;\5;\u02c7")
        buf.write("\n;\3;\5;\u02ca\n;\3;\3;\3;\5;\u02cf\n;\3;\5;\u02d2\n")
        buf.write(";\3;\3;\3<\3<\3<\3<\3<\3=\3=\3=\3=\3=\3>\3>\3>\3>\3>\3")
        buf.write("?\3?\3?\7?\u02e8\n?\f?\16?\u02eb\13?\3?\3?\3@\3@\3@\3")
        buf.write("@\3@\3@\3@\3@\3@\3@\3@\3@\3@\5@\u02fc\n@\3A\3A\3A\3A\3")
        buf.write("A\3A\5A\u0304\nA\3B\3B\3B\7B\u0309\nB\fB\16B\u030c\13")
        buf.write("B\3B\3B\3C\3C\3C\3C\3C\3D\3D\3D\3D\3D\3E\3E\3E\7E\u031d")
        buf.write("\nE\fE\16E\u0320\13E\3E\3E\3E\3E\3E\3E\3E\3E\3E\3E\3E")
        buf.write("\3E\5E\u032e\nE\3E\3E\3E\3E\5E\u0334\nE\3F\3F\3F\3F\3")
        buf.write("F\3F\3G\3G\3H\3H\3H\3H\3H\3H\3H\3H\3H\3H\6H\u0348\nH\r")
        buf.write("H\16H\u0349\3H\3H\3H\3H\3H\3H\3H\3H\3H\3H\3H\7H\u0357")
        buf.write("\nH\fH\16H\u035a\13H\3H\3H\3H\3H\3H\3H\3H\3H\3H\5H\u0365")
        buf.write("\nH\3I\3I\3I\7I\u036a\nI\fI\16I\u036d\13I\3I\3I\3I\3I")
        buf.write("\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3")
        buf.write("I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3")
        buf.write("I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3")
        buf.write("I\3I\3I\3I\3I\3I\3I\3I\3I\3I\3I\5I\u03b3\nI\3J\3J\3J\2")
        buf.write("\2K\2\4\6\b\n\f\16\20\22\24\26\30\32\34\36 \"$&(*,.\60")
        buf.write("\62\64\668:<>@BDFHJLNPRTVXZ\\^`bdfhjlnprtvxz|~\u0080\u0082")
        buf.write("\u0084\u0086\u0088\u008a\u008c\u008e\u0090\u0092\2\13")
        buf.write("\3\2 !\4\2\t\t%\'\3\2(,\3\2-\61\3\2*,\3\2\60\61\3\29:")
        buf.write("\4\2%%\'\'\4\2\36\37GG\2\u03de\2\u0096\3\2\2\2\4\u0098")
        buf.write("\3\2\2\2\6\u00b5\3\2\2\2\b\u00ba\3\2\2\2\n\u00c3\3\2\2")
        buf.write("\2\f\u00d9\3\2\2\2\16\u00dc\3\2\2\2\20\u00ed\3\2\2\2\22")
        buf.write("\u00ef\3\2\2\2\24\u00f1\3\2\2\2\26\u0101\3\2\2\2\30\u0104")
        buf.write("\3\2\2\2\32\u0109\3\2\2\2\34\u010b\3\2\2\2\36\u010d\3")
        buf.write("\2\2\2 \u0112\3\2\2\2\"\u011b\3\2\2\2$\u0120\3\2\2\2&")
        buf.write("\u0133\3\2\2\2(\u0136\3\2\2\2*\u013d\3\2\2\2,\u0145\3")
        buf.write("\2\2\2.\u0147\3\2\2\2\60\u0151\3\2\2\2\62\u0159\3\2\2")
        buf.write("\2\64\u0163\3\2\2\2\66\u0194\3\2\2\28\u0196\3\2\2\2:\u019c")
        buf.write("\3\2\2\2<\u01a8\3\2\2\2>\u01aa\3\2\2\2@\u01b4\3\2\2\2")
        buf.write("B\u01d4\3\2\2\2D\u01df\3\2\2\2F\u01ed\3\2\2\2H\u01ef\3")
        buf.write("\2\2\2J\u01f1\3\2\2\2L\u01f3\3\2\2\2N\u0206\3\2\2\2P\u0208")
        buf.write("\3\2\2\2R\u0215\3\2\2\2T\u0221\3\2\2\2V\u0232\3\2\2\2")
        buf.write("X\u0240\3\2\2\2Z\u024c\3\2\2\2\\\u024e\3\2\2\2^\u0250")
        buf.write("\3\2\2\2`\u0252\3\2\2\2b\u0260\3\2\2\2d\u026e\3\2\2\2")
        buf.write("f\u0270\3\2\2\2h\u0274\3\2\2\2j\u0294\3\2\2\2l\u02a8\3")
        buf.write("\2\2\2n\u02aa\3\2\2\2p\u02bd\3\2\2\2r\u02bf\3\2\2\2t\u02c1")
        buf.write("\3\2\2\2v\u02d5\3\2\2\2x\u02da\3\2\2\2z\u02df\3\2\2\2")
        buf.write("|\u02e4\3\2\2\2~\u02fb\3\2\2\2\u0080\u0303\3\2\2\2\u0082")
        buf.write("\u0305\3\2\2\2\u0084\u030f\3\2\2\2\u0086\u0314\3\2\2\2")
        buf.write("\u0088\u0333\3\2\2\2\u008a\u0335\3\2\2\2\u008c\u033b\3")
        buf.write("\2\2\2\u008e\u0364\3\2\2\2\u0090\u03b2\3\2\2\2\u0092\u03b4")
        buf.write("\3\2\2\2\u0094\u0097\5\4\3\2\u0095\u0097\5t;\2\u0096\u0094")
        buf.write("\3\2\2\2\u0096\u0095\3\2\2\2\u0097\3\3\2\2\2\u0098\u0099")
        buf.write("\7\3\2\2\u0099\u009a\7\4\2\2\u009a\u009c\5\6\4\2\u009b")
        buf.write("\u009d\5\b\5\2\u009c\u009b\3\2\2\2\u009c\u009d\3\2\2\2")
        buf.write("\u009d\u009f\3\2\2\2\u009e\u00a0\5\n\6\2\u009f\u009e\3")
        buf.write("\2\2\2\u009f\u00a0\3\2\2\2\u00a0\u00a2\3\2\2\2\u00a1\u00a3")
        buf.write("\5\36\20\2\u00a2\u00a1\3\2\2\2\u00a2\u00a3\3\2\2\2\u00a3")
        buf.write("\u00a5\3\2\2\2\u00a4\u00a6\5 \21\2\u00a5\u00a4\3\2\2\2")
        buf.write("\u00a5\u00a6\3\2\2\2\u00a6\u00a8\3\2\2\2\u00a7\u00a9\5")
        buf.write("\24\13\2\u00a8\u00a7\3\2\2\2\u00a8\u00a9\3\2\2\2\u00a9")
        buf.write("\u00ab\3\2\2\2\u00aa\u00ac\5*\26\2\u00ab\u00aa\3\2\2\2")
        buf.write("\u00ab\u00ac\3\2\2\2\u00ac\u00b0\3\2\2\2\u00ad\u00af\5")
        buf.write(",\27\2\u00ae\u00ad\3\2\2\2\u00af\u00b2\3\2\2\2\u00b0\u00ae")
        buf.write("\3\2\2\2\u00b0\u00b1\3\2\2\2\u00b1\u00b3\3\2\2\2\u00b2")
        buf.write("\u00b0\3\2\2\2\u00b3\u00b4\7\5\2\2\u00b4\5\3\2\2\2\u00b5")
        buf.write("\u00b6\7\3\2\2\u00b6\u00b7\7\6\2\2\u00b7\u00b8\5\u0092")
        buf.write("J\2\u00b8\u00b9\7\5\2\2\u00b9\7\3\2\2\2\u00ba\u00bb\7")
        buf.write("\3\2\2\u00bb\u00bd\7\7\2\2\u00bc\u00be\7F\2\2\u00bd\u00bc")
        buf.write("\3\2\2\2\u00be\u00bf\3\2\2\2\u00bf\u00bd\3\2\2\2\u00bf")
        buf.write("\u00c0\3\2\2\2\u00c0\u00c1\3\2\2\2\u00c1\u00c2\7\5\2\2")
        buf.write("\u00c2\t\3\2\2\2\u00c3\u00c4\7\3\2\2\u00c4\u00c5\7\b\2")
        buf.write("\2\u00c5\u00c6\5\f\7\2\u00c6\u00c7\7\5\2\2\u00c7\13\3")
        buf.write("\2\2\2\u00c8\u00ca\5\u0092J\2\u00c9\u00c8\3\2\2\2\u00ca")
        buf.write("\u00cd\3\2\2\2\u00cb\u00c9\3\2\2\2\u00cb\u00cc\3\2\2\2")
        buf.write("\u00cc\u00da\3\2\2\2\u00cd\u00cb\3\2\2\2\u00ce\u00d0\5")
        buf.write("\16\b\2\u00cf\u00ce\3\2\2\2\u00d0\u00d1\3\2\2\2\u00d1")
        buf.write("\u00cf\3\2\2\2\u00d1\u00d2\3\2\2\2\u00d2\u00d6\3\2\2\2")
        buf.write("\u00d3\u00d5\5\u0092J\2\u00d4\u00d3\3\2\2\2\u00d5\u00d8")
        buf.write("\3\2\2\2\u00d6\u00d4\3\2\2\2\u00d6\u00d7\3\2\2\2\u00d7")
        buf.write("\u00da\3\2\2\2\u00d8\u00d6\3\2\2\2\u00d9\u00cb\3\2\2\2")
        buf.write("\u00d9\u00cf\3\2\2\2\u00da\r\3\2\2\2\u00db\u00dd\5\u0092")
        buf.write("J\2\u00dc\u00db\3\2\2\2\u00dd\u00de\3\2\2\2\u00de\u00dc")
        buf.write("\3\2\2\2\u00de\u00df\3\2\2\2\u00df\u00e0\3\2\2\2\u00e0")
        buf.write("\u00e1\7\t\2\2\u00e1\u00e2\5\20\t\2\u00e2\17\3\2\2\2\u00e3")
        buf.write("\u00e4\7\3\2\2\u00e4\u00e6\7\n\2\2\u00e5\u00e7\5\22\n")
        buf.write("\2\u00e6\u00e5\3\2\2\2\u00e7\u00e8\3\2\2\2\u00e8\u00e6")
        buf.write("\3\2\2\2\u00e8\u00e9\3\2\2\2\u00e9\u00ea\3\2\2\2\u00ea")
        buf.write("\u00eb\7\5\2\2\u00eb\u00ee\3\2\2\2\u00ec\u00ee\5\22\n")
        buf.write("\2\u00ed\u00e3\3\2\2\2\u00ed\u00ec\3\2\2\2\u00ee\21\3")
        buf.write("\2\2\2\u00ef\u00f0\5\u0092J\2\u00f0\23\3\2\2\2\u00f1\u00f2")
        buf.write("\7\3\2\2\u00f2\u00f3\7\13\2\2\u00f3\u00f4\5\26\f\2\u00f4")
        buf.write("\u00f5\7\5\2\2\u00f5\25\3\2\2\2\u00f6\u00f8\5\30\r\2\u00f7")
        buf.write("\u00f6\3\2\2\2\u00f8\u00f9\3\2\2\2\u00f9\u00f7\3\2\2\2")
        buf.write("\u00f9\u00fa\3\2\2\2\u00fa\u00fd\3\2\2\2\u00fb\u00fc\7")
        buf.write("\t\2\2\u00fc\u00fe\5\34\17\2\u00fd\u00fb\3\2\2\2\u00fd")
        buf.write("\u00fe\3\2\2\2\u00fe\u0100\3\2\2\2\u00ff\u00f7\3\2\2\2")
        buf.write("\u0100\u0103\3\2\2\2\u0101\u00ff\3\2\2\2\u0101\u0102\3")
        buf.write("\2\2\2\u0102\27\3\2\2\2\u0103\u0101\3\2\2\2\u0104\u0105")
        buf.write("\7\3\2\2\u0105\u0106\5\32\16\2\u0106\u0107\5&\24\2\u0107")
        buf.write("\u0108\7\5\2\2\u0108\31\3\2\2\2\u0109\u010a\5\u0092J\2")
        buf.write("\u010a\33\3\2\2\2\u010b\u010c\7\f\2\2\u010c\35\3\2\2\2")
        buf.write("\u010d\u010e\7\3\2\2\u010e\u010f\7\r\2\2\u010f\u0110\5")
        buf.write("\f\7\2\u0110\u0111\7\5\2\2\u0111\37\3\2\2\2\u0112\u0113")
        buf.write("\7\3\2\2\u0113\u0115\7\16\2\2\u0114\u0116\5\"\22\2\u0115")
        buf.write("\u0114\3\2\2\2\u0116\u0117\3\2\2\2\u0117\u0115\3\2\2\2")
        buf.write("\u0117\u0118\3\2\2\2\u0118\u0119\3\2\2\2\u0119\u011a\7")
        buf.write("\5\2\2\u011a!\3\2\2\2\u011b\u011c\7\3\2\2\u011c\u011d")
        buf.write("\5$\23\2\u011d\u011e\5&\24\2\u011e\u011f\7\5\2\2\u011f")
        buf.write("#\3\2\2\2\u0120\u0121\5\u0092J\2\u0121%\3\2\2\2\u0122")
        buf.write("\u0124\7H\2\2\u0123\u0122\3\2\2\2\u0124\u0127\3\2\2\2")
        buf.write("\u0125\u0123\3\2\2\2\u0125\u0126\3\2\2\2\u0126\u0134\3")
        buf.write("\2\2\2\u0127\u0125\3\2\2\2\u0128\u012a\5(\25\2\u0129\u0128")
        buf.write("\3\2\2\2\u012a\u012b\3\2\2\2\u012b\u0129\3\2\2\2\u012b")
        buf.write("\u012c\3\2\2\2\u012c\u0130\3\2\2\2\u012d\u012f\7H\2\2")
        buf.write("\u012e\u012d\3\2\2\2\u012f\u0132\3\2\2\2\u0130\u012e\3")
        buf.write("\2\2\2\u0130\u0131\3\2\2\2\u0131\u0134\3\2\2\2\u0132\u0130")
        buf.write("\3\2\2\2\u0133\u0125\3\2\2\2\u0133\u0129\3\2\2\2\u0134")
        buf.write("\'\3\2\2\2\u0135\u0137\7H\2\2\u0136\u0135\3\2\2\2\u0137")
        buf.write("\u0138\3\2\2\2\u0138\u0136\3\2\2\2\u0138\u0139\3\2\2\2")
        buf.write("\u0139\u013a\3\2\2\2\u013a\u013b\7\t\2\2\u013b\u013c\5")
        buf.write("\20\t\2\u013c)\3\2\2\2\u013d\u013e\7\3\2\2\u013e\u013f")
        buf.write("\7\17\2\2\u013f\u0140\5\u0090I\2\u0140\u0141\7\5\2\2\u0141")
        buf.write("+\3\2\2\2\u0142\u0146\5.\30\2\u0143\u0146\5> \2\u0144")
        buf.write("\u0146\5L\'\2\u0145\u0142\3\2\2\2\u0145\u0143\3\2\2\2")
        buf.write("\u0145\u0144\3\2\2\2\u0146-\3\2\2\2\u0147\u0148\7\3\2")
        buf.write("\2\u0148\u0149\7\20\2\2\u0149\u014a\5\60\31\2\u014a\u014b")
        buf.write("\7\21\2\2\u014b\u014c\7\3\2\2\u014c\u014d\5&\24\2\u014d")
        buf.write("\u014e\7\5\2\2\u014e\u014f\5\62\32\2\u014f\u0150\7\5\2")
        buf.write("\2\u0150/\3\2\2\2\u0151\u0152\5\u0092J\2\u0152\61\3\2")
        buf.write("\2\2\u0153\u0157\7\22\2\2\u0154\u0155\7\3\2\2\u0155\u0158")
        buf.write("\7\5\2\2\u0156\u0158\5\64\33\2\u0157\u0154\3\2\2\2\u0157")
        buf.write("\u0156\3\2\2\2\u0158\u015a\3\2\2\2\u0159\u0153\3\2\2\2")
        buf.write("\u0159\u015a\3\2\2\2\u015a\u0161\3\2\2\2\u015b\u015f\7")
        buf.write("\23\2\2\u015c\u015d\7\3\2\2\u015d\u0160\7\5\2\2\u015e")
        buf.write("\u0160\5T+\2\u015f\u015c\3\2\2\2\u015f\u015e\3\2\2\2\u0160")
        buf.write("\u0162\3\2\2\2\u0161\u015b\3\2\2\2\u0161\u0162\3\2\2\2")
        buf.write("\u0162\63\3\2\2\2\u0163\u0164\5\66\34\2\u0164\65\3\2\2")
        buf.write("\2\u0165\u0195\5:\36\2\u0166\u0167\7\3\2\2\u0167\u016b")
        buf.write("\7\24\2\2\u0168\u016a\5\66\34\2\u0169\u0168\3\2\2\2\u016a")
        buf.write("\u016d\3\2\2\2\u016b\u0169\3\2\2\2\u016b\u016c\3\2\2\2")
        buf.write("\u016c\u016e\3\2\2\2\u016d\u016b\3\2\2\2\u016e\u0195\7")
        buf.write("\5\2\2\u016f\u0170\7\3\2\2\u0170\u0174\7\25\2\2\u0171")
        buf.write("\u0173\5\66\34\2\u0172\u0171\3\2\2\2\u0173\u0176\3\2\2")
        buf.write("\2\u0174\u0172\3\2\2\2\u0174\u0175\3\2\2\2\u0175\u0177")
        buf.write("\3\2\2\2\u0176\u0174\3\2\2\2\u0177\u0195\7\5\2\2\u0178")
        buf.write("\u0179\7\3\2\2\u0179\u017a\7\26\2\2\u017a\u017b\5\66\34")
        buf.write("\2\u017b\u017c\7\5\2\2\u017c\u0195\3\2\2\2\u017d\u017e")
        buf.write("\7\3\2\2\u017e\u017f\7\27\2\2\u017f\u0180\5\66\34\2\u0180")
        buf.write("\u0181\5\66\34\2\u0181\u0182\7\5\2\2\u0182\u0195\3\2\2")
        buf.write("\2\u0183\u0184\7\3\2\2\u0184\u0185\7\30\2\2\u0185\u0186")
        buf.write("\7\3\2\2\u0186\u0187\5&\24\2\u0187\u0188\7\5\2\2\u0188")
        buf.write("\u0189\5\66\34\2\u0189\u018a\7\5\2\2\u018a\u0195\3\2\2")
        buf.write("\2\u018b\u018c\7\3\2\2\u018c\u018d\7\31\2\2\u018d\u018e")
        buf.write("\7\3\2\2\u018e\u018f\5&\24\2\u018f\u0190\7\5\2\2\u0190")
        buf.write("\u0191\5\66\34\2\u0191\u0192\7\5\2\2\u0192\u0195\3\2\2")
        buf.write("\2\u0193\u0195\58\35\2\u0194\u0165\3\2\2\2\u0194\u0166")
        buf.write("\3\2\2\2\u0194\u016f\3\2\2\2\u0194\u0178\3\2\2\2\u0194")
        buf.write("\u017d\3\2\2\2\u0194\u0183\3\2\2\2\u0194\u018b\3\2\2\2")
        buf.write("\u0194\u0193\3\2\2\2\u0195\67\3\2\2\2\u0196\u0197\7\3")
        buf.write("\2\2\u0197\u0198\5^\60\2\u0198\u0199\5N(\2\u0199\u019a")
        buf.write("\5N(\2\u019a\u019b\7\5\2\2\u019b9\3\2\2\2\u019c\u019d")
        buf.write("\7\3\2\2\u019d\u01a1\5$\23\2\u019e\u01a0\5<\37\2\u019f")
        buf.write("\u019e\3\2\2\2\u01a0\u01a3\3\2\2\2\u01a1\u019f\3\2\2\2")
        buf.write("\u01a1\u01a2\3\2\2\2\u01a2\u01a4\3\2\2\2\u01a3\u01a1\3")
        buf.write("\2\2\2\u01a4\u01a5\7\5\2\2\u01a5;\3\2\2\2\u01a6\u01a9")
        buf.write("\5\u0092J\2\u01a7\u01a9\7H\2\2\u01a8\u01a6\3\2\2\2\u01a8")
        buf.write("\u01a7\3\2\2\2\u01a9=\3\2\2\2\u01aa\u01ab\7\3\2\2\u01ab")
        buf.write("\u01ac\7\32\2\2\u01ac\u01ad\5\60\31\2\u01ad\u01ae\7\21")
        buf.write("\2\2\u01ae\u01af\7\3\2\2\u01af\u01b0\5&\24\2\u01b0\u01b1")
        buf.write("\7\5\2\2\u01b1\u01b2\5@!\2\u01b2\u01b3\7\5\2\2\u01b3?")
        buf.write("\3\2\2\2\u01b4\u01b5\7\33\2\2\u01b5\u01b6\5b\62\2\u01b6")
        buf.write("\u01ba\7\34\2\2\u01b7\u01b8\7\3\2\2\u01b8\u01bb\7\5\2")
        buf.write("\2\u01b9\u01bb\5B\"\2\u01ba\u01b7\3\2\2\2\u01ba\u01b9")
        buf.write("\3\2\2\2\u01bb\u01bc\3\2\2\2\u01bc\u01c0\7\23\2\2\u01bd")
        buf.write("\u01be\7\3\2\2\u01be\u01c1\7\5\2\2\u01bf\u01c1\5j\66\2")
        buf.write("\u01c0\u01bd\3\2\2\2\u01c0\u01bf\3\2\2\2\u01c1A\3\2\2")
        buf.write("\2\u01c2\u01d5\5D#\2\u01c3\u01c4\7\3\2\2\u01c4\u01c8\7")
        buf.write("\24\2\2\u01c5\u01c7\5B\"\2\u01c6\u01c5\3\2\2\2\u01c7\u01ca")
        buf.write("\3\2\2\2\u01c8\u01c6\3\2\2\2\u01c8\u01c9\3\2\2\2\u01c9")
        buf.write("\u01cb\3\2\2\2\u01ca\u01c8\3\2\2\2\u01cb\u01d5\7\5\2\2")
        buf.write("\u01cc\u01cd\7\3\2\2\u01cd\u01ce\7\31\2\2\u01ce\u01cf")
        buf.write("\7\3\2\2\u01cf\u01d0\5&\24\2\u01d0\u01d1\7\5\2\2\u01d1")
        buf.write("\u01d2\5B\"\2\u01d2\u01d3\7\5\2\2\u01d3\u01d5\3\2\2\2")
        buf.write("\u01d4\u01c2\3\2\2\2\u01d4\u01c3\3\2\2\2\u01d4\u01cc\3")
        buf.write("\2\2\2\u01d5C\3\2\2\2\u01d6\u01e0\5F$\2\u01d7\u01d8\7")
        buf.write("\3\2\2\u01d8\u01da\7\35\2\2\u01d9\u01db\5\u0092J\2\u01da")
        buf.write("\u01d9\3\2\2\2\u01da\u01db\3\2\2\2\u01db\u01dc\3\2\2\2")
        buf.write("\u01dc\u01dd\5F$\2\u01dd\u01de\7\5\2\2\u01de\u01e0\3\2")
        buf.write("\2\2\u01df\u01d6\3\2\2\2\u01df\u01d7\3\2\2\2\u01e0E\3")
        buf.write("\2\2\2\u01e1\u01e2\7\3\2\2\u01e2\u01e3\7\36\2\2\u01e3")
        buf.write("\u01e4\5H%\2\u01e4\u01e5\5\66\34\2\u01e5\u01e6\7\5\2\2")
        buf.write("\u01e6\u01ee\3\2\2\2\u01e7\u01e8\7\3\2\2\u01e8\u01e9\7")
        buf.write("\37\2\2\u01e9\u01ea\5J&\2\u01ea\u01eb\5\66\34\2\u01eb")
        buf.write("\u01ec\7\5\2\2\u01ec\u01ee\3\2\2\2\u01ed\u01e1\3\2\2\2")
        buf.write("\u01ed\u01e7\3\2\2\2\u01eeG\3\2\2\2\u01ef\u01f0\t\2\2")
        buf.write("\2\u01f0I\3\2\2\2\u01f1\u01f2\7\"\2\2\u01f2K\3\2\2\2\u01f3")
        buf.write("\u01f4\7\3\2\2\u01f4\u01f5\7#\2\2\u01f5\u01f6\5&\24\2")
        buf.write("\u01f6\u01f7\5\66\34\2\u01f7\u01f8\7\5\2\2\u01f8M\3\2")
        buf.write("\2\2\u01f9\u0207\7I\2\2\u01fa\u01fb\7\3\2\2\u01fb\u01fc")
        buf.write("\5\\/\2\u01fc\u01fd\5N(\2\u01fd\u01fe\5P)\2\u01fe\u01ff")
        buf.write("\7\5\2\2\u01ff\u0207\3\2\2\2\u0200\u0201\7\3\2\2\u0201")
        buf.write("\u0202\7\t\2\2\u0202\u0203\5N(\2\u0203\u0204\7\5\2\2\u0204")
        buf.write("\u0207\3\2\2\2\u0205\u0207\5R*\2\u0206\u01f9\3\2\2\2\u0206")
        buf.write("\u01fa\3\2\2\2\u0206\u0200\3\2\2\2\u0206\u0205\3\2\2\2")
        buf.write("\u0207O\3\2\2\2\u0208\u0209\5N(\2\u0209Q\3\2\2\2\u020a")
        buf.write("\u020b\7\3\2\2\u020b\u020f\5\32\16\2\u020c\u020e\5<\37")
        buf.write("\2\u020d\u020c\3\2\2\2\u020e\u0211\3\2\2\2\u020f\u020d")
        buf.write("\3\2\2\2\u020f\u0210\3\2\2\2\u0210\u0212\3\2\2\2\u0211")
        buf.write("\u020f\3\2\2\2\u0212\u0213\7\5\2\2\u0213\u0216\3\2\2\2")
        buf.write("\u0214\u0216\5\32\16\2\u0215\u020a\3\2\2\2\u0215\u0214")
        buf.write("\3\2\2\2\u0216S\3\2\2\2\u0217\u0218\7\3\2\2\u0218\u021c")
        buf.write("\7\24\2\2\u0219\u021b\5V,\2\u021a\u0219\3\2\2\2\u021b")
        buf.write("\u021e\3\2\2\2\u021c\u021a\3\2\2\2\u021c\u021d\3\2\2\2")
        buf.write("\u021d\u021f\3\2\2\2\u021e\u021c\3\2\2\2\u021f\u0222\7")
        buf.write("\5\2\2\u0220\u0222\5V,\2\u0221\u0217\3\2\2\2\u0221\u0220")
        buf.write("\3\2\2\2\u0222U\3\2\2\2\u0223\u0224\7\3\2\2\u0224\u0225")
        buf.write("\7\31\2\2\u0225\u0226\7\3\2\2\u0226\u0227\5&\24\2\u0227")
        buf.write("\u0228\7\5\2\2\u0228\u0229\5T+\2\u0229\u022a\7\5\2\2\u022a")
        buf.write("\u0233\3\2\2\2\u022b\u022c\7\3\2\2\u022c\u022d\7$\2\2")
        buf.write("\u022d\u022e\5\66\34\2\u022e\u022f\5Z.\2\u022f\u0230\7")
        buf.write("\5\2\2\u0230\u0233\3\2\2\2\u0231\u0233\5X-\2\u0232\u0223")
        buf.write("\3\2\2\2\u0232\u022b\3\2\2\2\u0232\u0231\3\2\2\2\u0233")
        buf.write("W\3\2\2\2\u0234\u0235\7\3\2\2\u0235\u0236\5`\61\2\u0236")
        buf.write("\u0237\5R*\2\u0237\u0238\5N(\2\u0238\u0239\7\5\2\2\u0239")
        buf.write("\u0241\3\2\2\2\u023a\u023b\7\3\2\2\u023b\u023c\7\26\2")
        buf.write("\2\u023c\u023d\5:\36\2\u023d\u023e\7\5\2\2\u023e\u0241")
        buf.write("\3\2\2\2\u023f\u0241\5:\36\2\u0240\u0234\3\2\2\2\u0240")
        buf.write("\u023a\3\2\2\2\u0240\u023f\3\2\2\2\u0241Y\3\2\2\2\u0242")
        buf.write("\u0243\7\3\2\2\u0243\u0247\7\24\2\2\u0244\u0246\5X-\2")
        buf.write("\u0245\u0244\3\2\2\2\u0246\u0249\3\2\2\2\u0247\u0245\3")
        buf.write("\2\2\2\u0247\u0248\3\2\2\2\u0248\u024a\3\2\2\2\u0249\u0247")
        buf.write("\3\2\2\2\u024a\u024d\7\5\2\2\u024b\u024d\5X-\2\u024c\u0242")
        buf.write("\3\2\2\2\u024c\u024b\3\2\2\2\u024d[\3\2\2\2\u024e\u024f")
        buf.write("\t\3\2\2\u024f]\3\2\2\2\u0250\u0251\t\4\2\2\u0251_\3\2")
        buf.write("\2\2\u0252\u0253\t\5\2\2\u0253a\3\2\2\2\u0254\u0255\7")
        buf.write("\3\2\2\u0255\u0257\7\24\2\2\u0256\u0258\5d\63\2\u0257")
        buf.write("\u0256\3\2\2\2\u0258\u0259\3\2\2\2\u0259\u0257\3\2\2\2")
        buf.write("\u0259\u025a\3\2\2\2\u025a\u025b\3\2\2\2\u025b\u025c\7")
        buf.write("\5\2\2\u025c\u0261\3\2\2\2\u025d\u025e\7\3\2\2\u025e\u0261")
        buf.write("\7\5\2\2\u025f\u0261\5d\63\2\u0260\u0254\3\2\2\2\u0260")
        buf.write("\u025d\3\2\2\2\u0260\u025f\3\2\2\2\u0261c\3\2\2\2\u0262")
        buf.write("\u0263\7\3\2\2\u0263\u0264\5f\64\2\u0264\u0265\7\62\2")
        buf.write("\2\u0265\u0266\5h\65\2\u0266\u0267\7\5\2\2\u0267\u026f")
        buf.write("\3\2\2\2\u0268\u0269\7\3\2\2\u0269\u026a\7\36\2\2\u026a")
        buf.write("\u026b\5H%\2\u026b\u026c\5d\63\2\u026c\u026d\7\5\2\2\u026d")
        buf.write("\u026f\3\2\2\2\u026e\u0262\3\2\2\2\u026e\u0268\3\2\2\2")
        buf.write("\u026fe\3\2\2\2\u0270\u0271\t\6\2\2\u0271g\3\2\2\2\u0272")
        buf.write("\u0275\7I\2\2\u0273\u0275\5N(\2\u0274\u0272\3\2\2\2\u0274")
        buf.write("\u0273\3\2\2\2\u0275i\3\2\2\2\u0276\u0277\7\3\2\2\u0277")
        buf.write("\u027b\7\24\2\2\u0278\u027a\5j\66\2\u0279\u0278\3\2\2")
        buf.write("\2\u027a\u027d\3\2\2\2\u027b\u0279\3\2\2\2\u027b\u027c")
        buf.write("\3\2\2\2\u027c\u027e\3\2\2\2\u027d\u027b\3\2\2\2\u027e")
        buf.write("\u0295\7\5\2\2\u027f\u0295\5l\67\2\u0280\u0281\7\3\2\2")
        buf.write("\u0281\u0282\7\31\2\2\u0282\u0283\7\3\2\2\u0283\u0284")
        buf.write("\5&\24\2\u0284\u0285\7\5\2\2\u0285\u0286\5j\66\2\u0286")
        buf.write("\u0287\7\5\2\2\u0287\u0295\3\2\2\2\u0288\u0289\7\3\2\2")
        buf.write("\u0289\u028a\7$\2\2\u028a\u028b\5B\"\2\u028b\u028c\5l")
        buf.write("\67\2\u028c\u028d\7\5\2\2\u028d\u0295\3\2\2\2\u028e\u028f")
        buf.write("\7\3\2\2\u028f\u0290\5`\61\2\u0290\u0291\5R*\2\u0291\u0292")
        buf.write("\5p9\2\u0292\u0293\7\5\2\2\u0293\u0295\3\2\2\2\u0294\u0276")
        buf.write("\3\2\2\2\u0294\u027f\3\2\2\2\u0294\u0280\3\2\2\2\u0294")
        buf.write("\u0288\3\2\2\2\u0294\u028e\3\2\2\2\u0295k\3\2\2\2\u0296")
        buf.write("\u0297\7\3\2\2\u0297\u0298\7\36\2\2\u0298\u0299\5H%\2")
        buf.write("\u0299\u029a\5V,\2\u029a\u029b\7\5\2\2\u029b\u02a9\3\2")
        buf.write("\2\2\u029c\u029d\7\3\2\2\u029d\u029e\7\36\2\2\u029e\u029f")
        buf.write("\5H%\2\u029f\u02a0\5n8\2\u02a0\u02a1\7\5\2\2\u02a1\u02a9")
        buf.write("\3\2\2\2\u02a2\u02a3\7\3\2\2\u02a3\u02a4\5r:\2\u02a4\u02a5")
        buf.write("\5R*\2\u02a5\u02a6\5N(\2\u02a6\u02a7\7\5\2\2\u02a7\u02a9")
        buf.write("\3\2\2\2\u02a8\u0296\3\2\2\2\u02a8\u029c\3\2\2\2\u02a8")
        buf.write("\u02a2\3\2\2\2\u02a9m\3\2\2\2\u02aa\u02ab\7\3\2\2\u02ab")
        buf.write("\u02ac\5`\61\2\u02ac\u02ad\5R*\2\u02ad\u02ae\5p9\2\u02ae")
        buf.write("\u02af\7\5\2\2\u02afo\3\2\2\2\u02b0\u02b7\7\3\2\2\u02b1")
        buf.write("\u02b2\5\\/\2\u02b2\u02b3\5p9\2\u02b3\u02b4\5p9\2\u02b4")
        buf.write("\u02b8\3\2\2\2\u02b5\u02b6\7\t\2\2\u02b6\u02b8\5p9\2\u02b7")
        buf.write("\u02b1\3\2\2\2\u02b7\u02b5\3\2\2\2\u02b8\u02b9\3\2\2\2")
        buf.write("\u02b9\u02ba\7\5\2\2\u02ba\u02be\3\2\2\2\u02bb\u02be\7")
        buf.write("\62\2\2\u02bc\u02be\5N(\2\u02bd\u02b0\3\2\2\2\u02bd\u02bb")
        buf.write("\3\2\2\2\u02bd\u02bc\3\2\2\2\u02beq\3\2\2\2\u02bf\u02c0")
        buf.write("\t\7\2\2\u02c0s\3\2\2\2\u02c1\u02c2\7\3\2\2\u02c2\u02c3")
        buf.write("\7\4\2\2\u02c3\u02c4\5v<\2\u02c4\u02c6\5x=\2\u02c5\u02c7")
        buf.write("\5\b\5\2\u02c6\u02c5\3\2\2\2\u02c6\u02c7\3\2\2\2\u02c7")
        buf.write("\u02c9\3\2\2\2\u02c8\u02ca\5z>\2\u02c9\u02c8\3\2\2\2\u02c9")
        buf.write("\u02ca\3\2\2\2\u02ca\u02cb\3\2\2\2\u02cb\u02cc\5|?\2\u02cc")
        buf.write("\u02ce\5\u0084C\2\u02cd\u02cf\5\u0086D\2\u02ce\u02cd\3")
        buf.write("\2\2\2\u02ce\u02cf\3\2\2\2\u02cf\u02d1\3\2\2\2\u02d0\u02d2")
        buf.write("\5\u008aF\2\u02d1\u02d0\3\2\2\2\u02d1\u02d2\3\2\2\2\u02d2")
        buf.write("\u02d3\3\2\2\2\u02d3\u02d4\7\5\2\2\u02d4u\3\2\2\2\u02d5")
        buf.write("\u02d6\7\3\2\2\u02d6\u02d7\7\63\2\2\u02d7\u02d8\5\u0092")
        buf.write("J\2\u02d8\u02d9\7\5\2\2\u02d9w\3\2\2\2\u02da\u02db\7\3")
        buf.write("\2\2\u02db\u02dc\7\64\2\2\u02dc\u02dd\5\u0092J\2\u02dd")
        buf.write("\u02de\7\5\2\2\u02dey\3\2\2\2\u02df\u02e0\7\3\2\2\u02e0")
        buf.write("\u02e1\7\65\2\2\u02e1\u02e2\5\f\7\2\u02e2\u02e3\7\5\2")
        buf.write("\2\u02e3{\3\2\2\2\u02e4\u02e5\7\3\2\2\u02e5\u02e9\7\66")
        buf.write("\2\2\u02e6\u02e8\5~@\2\u02e7\u02e6\3\2\2\2\u02e8\u02eb")
        buf.write("\3\2\2\2\u02e9\u02e7\3\2\2\2\u02e9\u02ea\3\2\2\2\u02ea")
        buf.write("\u02ec\3\2\2\2\u02eb\u02e9\3\2\2\2\u02ec\u02ed\7\5\2\2")
        buf.write("\u02ed}\3\2\2\2\u02ee\u02fc\5\u0080A\2\u02ef\u02f0\7\3")
        buf.write("\2\2\u02f0\u02f1\7*\2\2\u02f1\u02f2\5R*\2\u02f2\u02f3")
        buf.write("\7I\2\2\u02f3\u02f4\7\5\2\2\u02f4\u02fc\3\2\2\2\u02f5")
        buf.write("\u02f6\7\3\2\2\u02f6\u02f7\7\36\2\2\u02f7\u02f8\7I\2\2")
        buf.write("\u02f8\u02f9\5\u0080A\2\u02f9\u02fa\7\5\2\2\u02fa\u02fc")
        buf.write("\3\2\2\2\u02fb\u02ee\3\2\2\2\u02fb\u02ef\3\2\2\2\u02fb")
        buf.write("\u02f5\3\2\2\2\u02fc\177\3\2\2\2\u02fd\u0304\5\u0082B")
        buf.write("\2\u02fe\u02ff\7\3\2\2\u02ff\u0300\7\26\2\2\u0300\u0301")
        buf.write("\5\u0082B\2\u0301\u0302\7\5\2\2\u0302\u0304\3\2\2\2\u0303")
        buf.write("\u02fd\3\2\2\2\u0303\u02fe\3\2\2\2\u0304\u0081\3\2\2\2")
        buf.write("\u0305\u0306\7\3\2\2\u0306\u030a\5$\23\2\u0307\u0309\5")
        buf.write("\u0092J\2\u0308\u0307\3\2\2\2\u0309\u030c\3\2\2\2\u030a")
        buf.write("\u0308\3\2\2\2\u030a\u030b\3\2\2\2\u030b\u030d\3\2\2\2")
        buf.write("\u030c\u030a\3\2\2\2\u030d\u030e\7\5\2\2\u030e\u0083\3")
        buf.write("\2\2\2\u030f\u0310\7\3\2\2\u0310\u0311\7\67\2\2\u0311")
        buf.write("\u0312\5\66\34\2\u0312\u0313\7\5\2\2\u0313\u0085\3\2\2")
        buf.write("\2\u0314\u0315\7\3\2\2\u0315\u0316\7\17\2\2\u0316\u0317")
        buf.write("\5\u0088E\2\u0317\u0318\7\5\2\2\u0318\u0087\3\2\2\2\u0319")
        buf.write("\u031a\7\3\2\2\u031a\u031e\7\24\2\2\u031b\u031d\5\u0088")
        buf.write("E\2\u031c\u031b\3\2\2\2\u031d\u0320\3\2\2\2\u031e\u031c")
        buf.write("\3\2\2\2\u031e\u031f\3\2\2\2\u031f\u0321\3\2\2\2\u0320")
        buf.write("\u031e\3\2\2\2\u0321\u0334\7\5\2\2\u0322\u0323\7\3\2\2")
        buf.write("\u0323\u0324\7\31\2\2\u0324\u0325\7\3\2\2\u0325\u0326")
        buf.write("\5&\24\2\u0326\u0327\7\5\2\2\u0327\u0328\5\u0088E\2\u0328")
        buf.write("\u0329\7\5\2\2\u0329\u0334\3\2\2\2\u032a\u032b\7\3\2\2")
        buf.write("\u032b\u032d\7\35\2\2\u032c\u032e\5\u0092J\2\u032d\u032c")
        buf.write("\3\2\2\2\u032d\u032e\3\2\2\2\u032e\u032f\3\2\2\2\u032f")
        buf.write("\u0330\5\u0090I\2\u0330\u0331\7\5\2\2\u0331\u0334\3\2")
        buf.write("\2\2\u0332\u0334\5\u0090I\2\u0333\u0319\3\2\2\2\u0333")
        buf.write("\u0322\3\2\2\2\u0333\u032a\3\2\2\2\u0333\u0332\3\2\2\2")
        buf.write("\u0334\u0089\3\2\2\2\u0335\u0336\7\3\2\2\u0336\u0337\7")
        buf.write("8\2\2\u0337\u0338\5\u008cG\2\u0338\u0339\5\u008eH\2\u0339")
        buf.write("\u033a\7\5\2\2\u033a\u008b\3\2\2\2\u033b\u033c\t\b\2\2")
        buf.write("\u033c\u008d\3\2\2\2\u033d\u033e\7\3\2\2\u033e\u033f\5")
        buf.write("\\/\2\u033f\u0340\5\u008eH\2\u0340\u0341\5\u008eH\2\u0341")
        buf.write("\u0342\7\5\2\2\u0342\u0365\3\2\2\2\u0343\u0344\7\3\2\2")
        buf.write("\u0344\u0345\t\t\2\2\u0345\u0347\5\u008eH\2\u0346\u0348")
        buf.write("\5\u008eH\2\u0347\u0346\3\2\2\2\u0348\u0349\3\2\2\2\u0349")
        buf.write("\u0347\3\2\2\2\u0349\u034a\3\2\2\2\u034a\u034b\3\2\2\2")
        buf.write("\u034b\u034c\7\5\2\2\u034c\u0365\3\2\2\2\u034d\u034e\7")
        buf.write("\3\2\2\u034e\u034f\7\t\2\2\u034f\u0350\5\u008eH\2\u0350")
        buf.write("\u0351\7\5\2\2\u0351\u0365\3\2\2\2\u0352\u0365\7I\2\2")
        buf.write("\u0353\u0354\7\3\2\2\u0354\u0358\5\32\16\2\u0355\u0357")
        buf.write("\5\u0092J\2\u0356\u0355\3\2\2\2\u0357\u035a\3\2\2\2\u0358")
        buf.write("\u0356\3\2\2\2\u0358\u0359\3\2\2\2\u0359\u035b\3\2\2\2")
        buf.write("\u035a\u0358\3\2\2\2\u035b\u035c\7\5\2\2\u035c\u0365\3")
        buf.write("\2\2\2\u035d\u0365\5\32\16\2\u035e\u0365\7;\2\2\u035f")
        buf.write("\u0360\7\3\2\2\u0360\u0361\7<\2\2\u0361\u0362\5\u0092")
        buf.write("J\2\u0362\u0363\7\5\2\2\u0363\u0365\3\2\2\2\u0364\u033d")
        buf.write("\3\2\2\2\u0364\u0343\3\2\2\2\u0364\u034d\3\2\2\2\u0364")
        buf.write("\u0352\3\2\2\2\u0364\u0353\3\2\2\2\u0364\u035d\3\2\2\2")
        buf.write("\u0364\u035e\3\2\2\2\u0364\u035f\3\2\2\2\u0365\u008f\3")
        buf.write("\2\2\2\u0366\u0367\7\3\2\2\u0367\u036b\7\24\2\2\u0368")
        buf.write("\u036a\5\u0090I\2\u0369\u0368\3\2\2\2\u036a\u036d\3\2")
        buf.write("\2\2\u036b\u0369\3\2\2\2\u036b\u036c\3\2\2\2\u036c\u036e")
        buf.write("\3\2\2\2\u036d\u036b\3\2\2\2\u036e\u03b3\7\5\2\2\u036f")
        buf.write("\u0370\7\3\2\2\u0370\u0371\7\31\2\2\u0371\u0372\7\3\2")
        buf.write("\2\u0372\u0373\5&\24\2\u0373\u0374\7\5\2\2\u0374\u0375")
        buf.write("\5\u0090I\2\u0375\u0376\7\5\2\2\u0376\u03b3\3\2\2\2\u0377")
        buf.write("\u0378\7\3\2\2\u0378\u0379\7\36\2\2\u0379\u037a\7!\2\2")
        buf.write("\u037a\u037b\5\66\34\2\u037b\u037c\7\5\2\2\u037c\u03b3")
        buf.write("\3\2\2\2\u037d\u037e\7\3\2\2\u037e\u037f\7=\2\2\u037f")
        buf.write("\u0380\5\66\34\2\u0380\u0381\7\5\2\2\u0381\u03b3\3\2\2")
        buf.write("\2\u0382\u0383\7\3\2\2\u0383\u0384\7>\2\2\u0384\u0385")
        buf.write("\5\66\34\2\u0385\u0386\7\5\2\2\u0386\u03b3\3\2\2\2\u0387")
        buf.write("\u0388\7\3\2\2\u0388\u0389\7?\2\2\u0389\u038a\7I\2\2\u038a")
        buf.write("\u038b\5\66\34\2\u038b\u038c\7\5\2\2\u038c\u03b3\3\2\2")
        buf.write("\2\u038d\u038e\7\3\2\2\u038e\u038f\7@\2\2\u038f\u0390")
        buf.write("\5\66\34\2\u0390\u0391\7\5\2\2\u0391\u03b3\3\2\2\2\u0392")
        buf.write("\u0393\7\3\2\2\u0393\u0394\7A\2\2\u0394\u0395\5\66\34")
        buf.write("\2\u0395\u0396\5\66\34\2\u0396\u0397\7\5\2\2\u0397\u03b3")
        buf.write("\3\2\2\2\u0398\u0399\7\3\2\2\u0399\u039a\7B\2\2\u039a")
        buf.write("\u039b\5\66\34\2\u039b\u039c\5\66\34\2\u039c\u039d\7\5")
        buf.write("\2\2\u039d\u03b3\3\2\2\2\u039e\u039f\7\3\2\2\u039f\u03a0")
        buf.write("\7C\2\2\u03a0\u03a1\7I\2\2\u03a1\u03a2\5\66\34\2\u03a2")
        buf.write("\u03a3\5\66\34\2\u03a3\u03a4\7\5\2\2\u03a4\u03b3\3\2\2")
        buf.write("\2\u03a5\u03a6\7\3\2\2\u03a6\u03a7\7D\2\2\u03a7\u03a8")
        buf.write("\7I\2\2\u03a8\u03a9\7I\2\2\u03a9\u03aa\5\66\34\2\u03aa")
        buf.write("\u03ab\7\5\2\2\u03ab\u03b3\3\2\2\2\u03ac\u03ad\7\3\2\2")
        buf.write("\u03ad\u03ae\7E\2\2\u03ae\u03af\7I\2\2\u03af\u03b0\5\66")
        buf.write("\34\2\u03b0\u03b1\7\5\2\2\u03b1\u03b3\3\2\2\2\u03b2\u0366")
        buf.write("\3\2\2\2\u03b2\u036f\3\2\2\2\u03b2\u0377\3\2\2\2\u03b2")
        buf.write("\u037d\3\2\2\2\u03b2\u0382\3\2\2\2\u03b2\u0387\3\2\2\2")
        buf.write("\u03b2\u038d\3\2\2\2\u03b2\u0392\3\2\2\2\u03b2\u0398\3")
        buf.write("\2\2\2\u03b2\u039e\3\2\2\2\u03b2\u03a5\3\2\2\2\u03b2\u03ac")
        buf.write("\3\2\2\2\u03b3\u0091\3\2\2\2\u03b4\u03b5\t\n\2\2\u03b5")
        buf.write("\u0093\3\2\2\2N\u0096\u009c\u009f\u00a2\u00a5\u00a8\u00ab")
        buf.write("\u00b0\u00bf\u00cb\u00d1\u00d6\u00d9\u00de\u00e8\u00ed")
        buf.write("\u00f9\u00fd\u0101\u0117\u0125\u012b\u0130\u0133\u0138")
        buf.write("\u0145\u0157\u0159\u015f\u0161\u016b\u0174\u0194\u01a1")
        buf.write("\u01a8\u01ba\u01c0\u01c8\u01d4\u01da\u01df\u01ed\u0206")
        buf.write("\u020f\u0215\u021c\u0221\u0232\u0240\u0247\u024c\u0259")
        buf.write("\u0260\u026e\u0274\u027b\u0294\u02a8\u02b7\u02bd\u02c6")
        buf.write("\u02c9\u02ce\u02d1\u02e9\u02fb\u0303\u030a\u031e\u032d")
        buf.write("\u0333\u0349\u0358\u0364\u036b\u03b2")
        return buf.getvalue()


class pddlParser ( Parser ):

    grammarFileName = "pddl.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "'('", "'define'", "')'", "'domain'", 
                     "':requirements'", "':types'", "'-'", "'either'", "':functions'", 
                     "'number'", "':constants'", "':predicates'", "':constraints'", 
                     "':action'", "':parameters'", "':precondition'", "':effect'", 
                     "'and'", "'or'", "'not'", "'imply'", "'exists'", "'forall'", 
                     "':durative-action'", "':duration'", "':condition'", 
                     "'preference'", "'at'", "'over'", "'start'", "'end'", 
                     "'all'", "':derived'", "'when'", "'*'", "'+'", "'/'", 
                     "'>'", "'<'", "'='", "'>='", "'<='", "'assign'", "'scale-up'", 
                     "'scale-down'", "'increase'", "'decrease'", "'?duration'", 
                     "'problem'", "':domain'", "':objects'", "':init'", 
                     "':goal'", "':metric'", "'minimize'", "'maximize'", 
                     "'total-time'", "'is-violated'", "'always'", "'sometime'", 
                     "'within'", "'at-most-once'", "'sometime-after'", "'sometime-before'", 
                     "'always-within'", "'hold-during'", "'hold-after'" ]

    symbolicNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "REQUIRE_KEY", "NAME", "VARIABLE", "NUMBER", "LINE_COMMENT", 
                      "WHITESPACE", "DOMAIN", "DOMAIN_NAME", "REQUIREMENTS", 
                      "TYPES", "EITHER_TYPE", "CONSTANTS", "FUNCTIONS", 
                      "PREDICATES", "ACTION", "DURATIVE_ACTION", "PROBLEM", 
                      "PROBLEM_NAME", "PROBLEM_DOMAIN", "OBJECTS", "INIT", 
                      "FUNC_HEAD", "PRECONDITION", "EFFECT", "AND_GD", "OR_GD", 
                      "NOT_GD", "IMPLY_GD", "EXISTS_GD", "FORALL_GD", "COMPARISON_GD", 
                      "AND_EFFECT", "FORALL_EFFECT", "WHEN_EFFECT", "ASSIGN_EFFECT", 
                      "NOT_EFFECT", "PRED_HEAD", "GOAL", "BINARY_OP", "UNARY_MINUS", 
                      "INIT_EQ", "INIT_AT", "NOT_PRED_INIT", "PRED_INST", 
                      "PROBLEM_CONSTRAINT", "PROBLEM_METRIC" ]

    RULE_pddlDoc = 0
    RULE_domain = 1
    RULE_domainName = 2
    RULE_requireDef = 3
    RULE_typesDef = 4
    RULE_typedNameList = 5
    RULE_singleTypeNameList = 6
    RULE_r_type = 7
    RULE_primType = 8
    RULE_functionsDef = 9
    RULE_functionList = 10
    RULE_atomicFunctionSkeleton = 11
    RULE_functionSymbol = 12
    RULE_functionType = 13
    RULE_constantsDef = 14
    RULE_predicatesDef = 15
    RULE_atomicFormulaSkeleton = 16
    RULE_predicate = 17
    RULE_typedVariableList = 18
    RULE_singleTypeVarList = 19
    RULE_constraints = 20
    RULE_structureDef = 21
    RULE_actionDef = 22
    RULE_actionSymbol = 23
    RULE_actionDefBody = 24
    RULE_precondition = 25
    RULE_goalDesc = 26
    RULE_fComp = 27
    RULE_atomicTermFormula = 28
    RULE_term = 29
    RULE_durativeActionDef = 30
    RULE_daDefBody = 31
    RULE_daGD = 32
    RULE_prefTimedGD = 33
    RULE_timedGD = 34
    RULE_timeSpecifier = 35
    RULE_interval = 36
    RULE_derivedDef = 37
    RULE_fExp = 38
    RULE_fExp2 = 39
    RULE_fHead = 40
    RULE_effect = 41
    RULE_cEffect = 42
    RULE_pEffect = 43
    RULE_condEffect = 44
    RULE_binaryOp = 45
    RULE_binaryComp = 46
    RULE_assignOp = 47
    RULE_durationConstraint = 48
    RULE_simpleDurationConstraint = 49
    RULE_durOp = 50
    RULE_durValue = 51
    RULE_daEffect = 52
    RULE_timedEffect = 53
    RULE_fAssignDA = 54
    RULE_fExpDA = 55
    RULE_assignOpT = 56
    RULE_problem = 57
    RULE_problemDecl = 58
    RULE_problemDomain = 59
    RULE_objectDecl = 60
    RULE_init = 61
    RULE_initEl = 62
    RULE_nameLiteral = 63
    RULE_atomicNameFormula = 64
    RULE_goal = 65
    RULE_probConstraints = 66
    RULE_prefConGD = 67
    RULE_metricSpec = 68
    RULE_optimization = 69
    RULE_metricFExp = 70
    RULE_conGD = 71
    RULE_name = 72

    ruleNames =  [ "pddlDoc", "domain", "domainName", "requireDef", "typesDef", 
                   "typedNameList", "singleTypeNameList", "r_type", "primType", 
                   "functionsDef", "functionList", "atomicFunctionSkeleton", 
                   "functionSymbol", "functionType", "constantsDef", "predicatesDef", 
                   "atomicFormulaSkeleton", "predicate", "typedVariableList", 
                   "singleTypeVarList", "constraints", "structureDef", "actionDef", 
                   "actionSymbol", "actionDefBody", "precondition", "goalDesc", 
                   "fComp", "atomicTermFormula", "term", "durativeActionDef", 
                   "daDefBody", "daGD", "prefTimedGD", "timedGD", "timeSpecifier", 
                   "interval", "derivedDef", "fExp", "fExp2", "fHead", "effect", 
                   "cEffect", "pEffect", "condEffect", "binaryOp", "binaryComp", 
                   "assignOp", "durationConstraint", "simpleDurationConstraint", 
                   "durOp", "durValue", "daEffect", "timedEffect", "fAssignDA", 
                   "fExpDA", "assignOpT", "problem", "problemDecl", "problemDomain", 
                   "objectDecl", "init", "initEl", "nameLiteral", "atomicNameFormula", 
                   "goal", "probConstraints", "prefConGD", "metricSpec", 
                   "optimization", "metricFExp", "conGD", "name" ]

    EOF = Token.EOF
    T__0=1
    T__1=2
    T__2=3
    T__3=4
    T__4=5
    T__5=6
    T__6=7
    T__7=8
    T__8=9
    T__9=10
    T__10=11
    T__11=12
    T__12=13
    T__13=14
    T__14=15
    T__15=16
    T__16=17
    T__17=18
    T__18=19
    T__19=20
    T__20=21
    T__21=22
    T__22=23
    T__23=24
    T__24=25
    T__25=26
    T__26=27
    T__27=28
    T__28=29
    T__29=30
    T__30=31
    T__31=32
    T__32=33
    T__33=34
    T__34=35
    T__35=36
    T__36=37
    T__37=38
    T__38=39
    T__39=40
    T__40=41
    T__41=42
    T__42=43
    T__43=44
    T__44=45
    T__45=46
    T__46=47
    T__47=48
    T__48=49
    T__49=50
    T__50=51
    T__51=52
    T__52=53
    T__53=54
    T__54=55
    T__55=56
    T__56=57
    T__57=58
    T__58=59
    T__59=60
    T__60=61
    T__61=62
    T__62=63
    T__63=64
    T__64=65
    T__65=66
    T__66=67
    REQUIRE_KEY=68
    NAME=69
    VARIABLE=70
    NUMBER=71
    LINE_COMMENT=72
    WHITESPACE=73
    DOMAIN=74
    DOMAIN_NAME=75
    REQUIREMENTS=76
    TYPES=77
    EITHER_TYPE=78
    CONSTANTS=79
    FUNCTIONS=80
    PREDICATES=81
    ACTION=82
    DURATIVE_ACTION=83
    PROBLEM=84
    PROBLEM_NAME=85
    PROBLEM_DOMAIN=86
    OBJECTS=87
    INIT=88
    FUNC_HEAD=89
    PRECONDITION=90
    EFFECT=91
    AND_GD=92
    OR_GD=93
    NOT_GD=94
    IMPLY_GD=95
    EXISTS_GD=96
    FORALL_GD=97
    COMPARISON_GD=98
    AND_EFFECT=99
    FORALL_EFFECT=100
    WHEN_EFFECT=101
    ASSIGN_EFFECT=102
    NOT_EFFECT=103
    PRED_HEAD=104
    GOAL=105
    BINARY_OP=106
    UNARY_MINUS=107
    INIT_EQ=108
    INIT_AT=109
    NOT_PRED_INIT=110
    PRED_INST=111
    PROBLEM_CONSTRAINT=112
    PROBLEM_METRIC=113

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.7")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None



    class PddlDocContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def domain(self):
            return self.getTypedRuleContext(pddlParser.DomainContext,0)


        def problem(self):
            return self.getTypedRuleContext(pddlParser.ProblemContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_pddlDoc

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPddlDoc" ):
                listener.enterPddlDoc(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPddlDoc" ):
                listener.exitPddlDoc(self)




    def pddlDoc(self):

        localctx = pddlParser.PddlDocContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_pddlDoc)
        try:
            self.state = 148
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,0,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 146
                self.domain()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 147
                self.problem()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DomainContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def domainName(self):
            return self.getTypedRuleContext(pddlParser.DomainNameContext,0)


        def requireDef(self):
            return self.getTypedRuleContext(pddlParser.RequireDefContext,0)


        def typesDef(self):
            return self.getTypedRuleContext(pddlParser.TypesDefContext,0)


        def constantsDef(self):
            return self.getTypedRuleContext(pddlParser.ConstantsDefContext,0)


        def predicatesDef(self):
            return self.getTypedRuleContext(pddlParser.PredicatesDefContext,0)


        def functionsDef(self):
            return self.getTypedRuleContext(pddlParser.FunctionsDefContext,0)


        def constraints(self):
            return self.getTypedRuleContext(pddlParser.ConstraintsContext,0)


        def structureDef(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.StructureDefContext)
            else:
                return self.getTypedRuleContext(pddlParser.StructureDefContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_domain

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDomain" ):
                listener.enterDomain(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDomain" ):
                listener.exitDomain(self)




    def domain(self):

        localctx = pddlParser.DomainContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_domain)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 150
            self.match(pddlParser.T__0)
            self.state = 151
            self.match(pddlParser.T__1)
            self.state = 152
            self.domainName()
            self.state = 154
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,1,self._ctx)
            if la_ == 1:
                self.state = 153
                self.requireDef()


            self.state = 157
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,2,self._ctx)
            if la_ == 1:
                self.state = 156
                self.typesDef()


            self.state = 160
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,3,self._ctx)
            if la_ == 1:
                self.state = 159
                self.constantsDef()


            self.state = 163
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,4,self._ctx)
            if la_ == 1:
                self.state = 162
                self.predicatesDef()


            self.state = 166
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,5,self._ctx)
            if la_ == 1:
                self.state = 165
                self.functionsDef()


            self.state = 169
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,6,self._ctx)
            if la_ == 1:
                self.state = 168
                self.constraints()


            self.state = 174
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==pddlParser.T__0:
                self.state = 171
                self.structureDef()
                self.state = 176
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 177
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DomainNameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_domainName

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDomainName" ):
                listener.enterDomainName(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDomainName" ):
                listener.exitDomainName(self)




    def domainName(self):

        localctx = pddlParser.DomainNameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_domainName)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 179
            self.match(pddlParser.T__0)
            self.state = 180
            self.match(pddlParser.T__3)
            self.state = 181
            self.name()
            self.state = 182
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class RequireDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REQUIRE_KEY(self, i:int=None):
            if i is None:
                return self.getTokens(pddlParser.REQUIRE_KEY)
            else:
                return self.getToken(pddlParser.REQUIRE_KEY, i)

        def getRuleIndex(self):
            return pddlParser.RULE_requireDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRequireDef" ):
                listener.enterRequireDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRequireDef" ):
                listener.exitRequireDef(self)




    def requireDef(self):

        localctx = pddlParser.RequireDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_requireDef)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 184
            self.match(pddlParser.T__0)
            self.state = 185
            self.match(pddlParser.T__4)
            self.state = 187 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 186
                self.match(pddlParser.REQUIRE_KEY)
                self.state = 189 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==pddlParser.REQUIRE_KEY):
                    break

            self.state = 191
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TypesDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typedNameList(self):
            return self.getTypedRuleContext(pddlParser.TypedNameListContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_typesDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypesDef" ):
                listener.enterTypesDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypesDef" ):
                listener.exitTypesDef(self)




    def typesDef(self):

        localctx = pddlParser.TypesDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_typesDef)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 193
            self.match(pddlParser.T__0)
            self.state = 194
            self.match(pddlParser.T__5)
            self.state = 195
            self.typedNameList()
            self.state = 196
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TypedNameListContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.NameContext)
            else:
                return self.getTypedRuleContext(pddlParser.NameContext,i)


        def singleTypeNameList(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.SingleTypeNameListContext)
            else:
                return self.getTypedRuleContext(pddlParser.SingleTypeNameListContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_typedNameList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypedNameList" ):
                listener.enterTypedNameList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypedNameList" ):
                listener.exitTypedNameList(self)




    def typedNameList(self):

        localctx = pddlParser.TypedNameListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_typedNameList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 215
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,12,self._ctx)
            if la_ == 1:
                self.state = 201
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0):
                    self.state = 198
                    self.name()
                    self.state = 203
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass

            elif la_ == 2:
                self.state = 205 
                self._errHandler.sync(self)
                _alt = 1
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt == 1:
                        self.state = 204
                        self.singleTypeNameList()

                    else:
                        raise NoViableAltException(self)
                    self.state = 207 
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,10,self._ctx)

                self.state = 212
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0):
                    self.state = 209
                    self.name()
                    self.state = 214
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class SingleTypeNameListContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.t = None # R_typeContext

        def r_type(self):
            return self.getTypedRuleContext(pddlParser.R_typeContext,0)


        def name(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.NameContext)
            else:
                return self.getTypedRuleContext(pddlParser.NameContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_singleTypeNameList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSingleTypeNameList" ):
                listener.enterSingleTypeNameList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSingleTypeNameList" ):
                listener.exitSingleTypeNameList(self)




    def singleTypeNameList(self):

        localctx = pddlParser.SingleTypeNameListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_singleTypeNameList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 218 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 217
                self.name()
                self.state = 220 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0)):
                    break

            self.state = 222
            self.match(pddlParser.T__6)
            self.state = 223
            localctx.t = self.r_type()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class R_typeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def primType(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.PrimTypeContext)
            else:
                return self.getTypedRuleContext(pddlParser.PrimTypeContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_r_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterR_type" ):
                listener.enterR_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitR_type" ):
                listener.exitR_type(self)




    def r_type(self):

        localctx = pddlParser.R_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_r_type)
        self._la = 0 # Token type
        try:
            self.state = 235
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [pddlParser.T__0]:
                self.enterOuterAlt(localctx, 1)
                self.state = 225
                self.match(pddlParser.T__0)
                self.state = 226
                self.match(pddlParser.T__7)
                self.state = 228 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 227
                    self.primType()
                    self.state = 230 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0)):
                        break

                self.state = 232
                self.match(pddlParser.T__2)
                pass
            elif token in [pddlParser.T__27, pddlParser.T__28, pddlParser.NAME]:
                self.enterOuterAlt(localctx, 2)
                self.state = 234
                self.primType()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class PrimTypeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_primType

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrimType" ):
                listener.enterPrimType(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrimType" ):
                listener.exitPrimType(self)




    def primType(self):

        localctx = pddlParser.PrimTypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_primType)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 237
            self.name()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FunctionsDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def functionList(self):
            return self.getTypedRuleContext(pddlParser.FunctionListContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_functionsDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunctionsDef" ):
                listener.enterFunctionsDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunctionsDef" ):
                listener.exitFunctionsDef(self)




    def functionsDef(self):

        localctx = pddlParser.FunctionsDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_functionsDef)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 239
            self.match(pddlParser.T__0)
            self.state = 240
            self.match(pddlParser.T__8)
            self.state = 241
            self.functionList()
            self.state = 242
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FunctionListContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def atomicFunctionSkeleton(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.AtomicFunctionSkeletonContext)
            else:
                return self.getTypedRuleContext(pddlParser.AtomicFunctionSkeletonContext,i)


        def functionType(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.FunctionTypeContext)
            else:
                return self.getTypedRuleContext(pddlParser.FunctionTypeContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_functionList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunctionList" ):
                listener.enterFunctionList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunctionList" ):
                listener.exitFunctionList(self)




    def functionList(self):

        localctx = pddlParser.FunctionListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_functionList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 255
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==pddlParser.T__0:
                self.state = 245 
                self._errHandler.sync(self)
                _alt = 1
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt == 1:
                        self.state = 244
                        self.atomicFunctionSkeleton()

                    else:
                        raise NoViableAltException(self)
                    self.state = 247 
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,16,self._ctx)

                self.state = 251
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==pddlParser.T__6:
                    self.state = 249
                    self.match(pddlParser.T__6)
                    self.state = 250
                    self.functionType()


                self.state = 257
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class AtomicFunctionSkeletonContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def functionSymbol(self):
            return self.getTypedRuleContext(pddlParser.FunctionSymbolContext,0)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_atomicFunctionSkeleton

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAtomicFunctionSkeleton" ):
                listener.enterAtomicFunctionSkeleton(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAtomicFunctionSkeleton" ):
                listener.exitAtomicFunctionSkeleton(self)




    def atomicFunctionSkeleton(self):

        localctx = pddlParser.AtomicFunctionSkeletonContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_atomicFunctionSkeleton)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 258
            self.match(pddlParser.T__0)
            self.state = 259
            self.functionSymbol()
            self.state = 260
            self.typedVariableList()
            self.state = 261
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FunctionSymbolContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_functionSymbol

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunctionSymbol" ):
                listener.enterFunctionSymbol(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunctionSymbol" ):
                listener.exitFunctionSymbol(self)




    def functionSymbol(self):

        localctx = pddlParser.FunctionSymbolContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_functionSymbol)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 263
            self.name()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FunctionTypeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_functionType

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunctionType" ):
                listener.enterFunctionType(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunctionType" ):
                listener.exitFunctionType(self)




    def functionType(self):

        localctx = pddlParser.FunctionTypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_functionType)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 265
            self.match(pddlParser.T__9)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ConstantsDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typedNameList(self):
            return self.getTypedRuleContext(pddlParser.TypedNameListContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_constantsDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstantsDef" ):
                listener.enterConstantsDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstantsDef" ):
                listener.exitConstantsDef(self)




    def constantsDef(self):

        localctx = pddlParser.ConstantsDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_constantsDef)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 267
            self.match(pddlParser.T__0)
            self.state = 268
            self.match(pddlParser.T__10)
            self.state = 269
            self.typedNameList()
            self.state = 270
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class PredicatesDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def atomicFormulaSkeleton(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.AtomicFormulaSkeletonContext)
            else:
                return self.getTypedRuleContext(pddlParser.AtomicFormulaSkeletonContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_predicatesDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPredicatesDef" ):
                listener.enterPredicatesDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPredicatesDef" ):
                listener.exitPredicatesDef(self)




    def predicatesDef(self):

        localctx = pddlParser.PredicatesDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_predicatesDef)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 272
            self.match(pddlParser.T__0)
            self.state = 273
            self.match(pddlParser.T__11)
            self.state = 275 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 274
                self.atomicFormulaSkeleton()
                self.state = 277 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==pddlParser.T__0):
                    break

            self.state = 279
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class AtomicFormulaSkeletonContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def predicate(self):
            return self.getTypedRuleContext(pddlParser.PredicateContext,0)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_atomicFormulaSkeleton

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAtomicFormulaSkeleton" ):
                listener.enterAtomicFormulaSkeleton(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAtomicFormulaSkeleton" ):
                listener.exitAtomicFormulaSkeleton(self)




    def atomicFormulaSkeleton(self):

        localctx = pddlParser.AtomicFormulaSkeletonContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_atomicFormulaSkeleton)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 281
            self.match(pddlParser.T__0)
            self.state = 282
            self.predicate()
            self.state = 283
            self.typedVariableList()
            self.state = 284
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class PredicateContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_predicate

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPredicate" ):
                listener.enterPredicate(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPredicate" ):
                listener.exitPredicate(self)




    def predicate(self):

        localctx = pddlParser.PredicateContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_predicate)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 286
            self.name()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TypedVariableListContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def VARIABLE(self, i:int=None):
            if i is None:
                return self.getTokens(pddlParser.VARIABLE)
            else:
                return self.getToken(pddlParser.VARIABLE, i)

        def singleTypeVarList(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.SingleTypeVarListContext)
            else:
                return self.getTypedRuleContext(pddlParser.SingleTypeVarListContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_typedVariableList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTypedVariableList" ):
                listener.enterTypedVariableList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTypedVariableList" ):
                listener.exitTypedVariableList(self)




    def typedVariableList(self):

        localctx = pddlParser.TypedVariableListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_typedVariableList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 305
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,23,self._ctx)
            if la_ == 1:
                self.state = 291
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.VARIABLE:
                    self.state = 288
                    self.match(pddlParser.VARIABLE)
                    self.state = 293
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass

            elif la_ == 2:
                self.state = 295 
                self._errHandler.sync(self)
                _alt = 1
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt == 1:
                        self.state = 294
                        self.singleTypeVarList()

                    else:
                        raise NoViableAltException(self)
                    self.state = 297 
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,21,self._ctx)

                self.state = 302
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.VARIABLE:
                    self.state = 299
                    self.match(pddlParser.VARIABLE)
                    self.state = 304
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class SingleTypeVarListContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.t = None # R_typeContext

        def r_type(self):
            return self.getTypedRuleContext(pddlParser.R_typeContext,0)


        def VARIABLE(self, i:int=None):
            if i is None:
                return self.getTokens(pddlParser.VARIABLE)
            else:
                return self.getToken(pddlParser.VARIABLE, i)

        def getRuleIndex(self):
            return pddlParser.RULE_singleTypeVarList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSingleTypeVarList" ):
                listener.enterSingleTypeVarList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSingleTypeVarList" ):
                listener.exitSingleTypeVarList(self)




    def singleTypeVarList(self):

        localctx = pddlParser.SingleTypeVarListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_singleTypeVarList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 308 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 307
                self.match(pddlParser.VARIABLE)
                self.state = 310 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==pddlParser.VARIABLE):
                    break

            self.state = 312
            self.match(pddlParser.T__6)
            self.state = 313
            localctx.t = self.r_type()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ConstraintsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def conGD(self):
            return self.getTypedRuleContext(pddlParser.ConGDContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_constraints

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstraints" ):
                listener.enterConstraints(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstraints" ):
                listener.exitConstraints(self)




    def constraints(self):

        localctx = pddlParser.ConstraintsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_constraints)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 315
            self.match(pddlParser.T__0)
            self.state = 316
            self.match(pddlParser.T__12)
            self.state = 317
            self.conGD()
            self.state = 318
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class StructureDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def actionDef(self):
            return self.getTypedRuleContext(pddlParser.ActionDefContext,0)


        def durativeActionDef(self):
            return self.getTypedRuleContext(pddlParser.DurativeActionDefContext,0)


        def derivedDef(self):
            return self.getTypedRuleContext(pddlParser.DerivedDefContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_structureDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStructureDef" ):
                listener.enterStructureDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStructureDef" ):
                listener.exitStructureDef(self)




    def structureDef(self):

        localctx = pddlParser.StructureDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_structureDef)
        try:
            self.state = 323
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,25,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 320
                self.actionDef()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 321
                self.durativeActionDef()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 322
                self.derivedDef()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ActionDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def actionSymbol(self):
            return self.getTypedRuleContext(pddlParser.ActionSymbolContext,0)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def actionDefBody(self):
            return self.getTypedRuleContext(pddlParser.ActionDefBodyContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_actionDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterActionDef" ):
                listener.enterActionDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitActionDef" ):
                listener.exitActionDef(self)




    def actionDef(self):

        localctx = pddlParser.ActionDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_actionDef)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 325
            self.match(pddlParser.T__0)
            self.state = 326
            self.match(pddlParser.T__13)
            self.state = 327
            self.actionSymbol()
            self.state = 328
            self.match(pddlParser.T__14)
            self.state = 329
            self.match(pddlParser.T__0)
            self.state = 330
            self.typedVariableList()
            self.state = 331
            self.match(pddlParser.T__2)
            self.state = 332
            self.actionDefBody()
            self.state = 333
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ActionSymbolContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_actionSymbol

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterActionSymbol" ):
                listener.enterActionSymbol(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitActionSymbol" ):
                listener.exitActionSymbol(self)




    def actionSymbol(self):

        localctx = pddlParser.ActionSymbolContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_actionSymbol)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 335
            self.name()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ActionDefBodyContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def precondition(self):
            return self.getTypedRuleContext(pddlParser.PreconditionContext,0)


        def effect(self):
            return self.getTypedRuleContext(pddlParser.EffectContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_actionDefBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterActionDefBody" ):
                listener.enterActionDefBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitActionDefBody" ):
                listener.exitActionDefBody(self)




    def actionDefBody(self):

        localctx = pddlParser.ActionDefBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_actionDefBody)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 343
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==pddlParser.T__15:
                self.state = 337
                self.match(pddlParser.T__15)
                self.state = 341
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,26,self._ctx)
                if la_ == 1:
                    self.state = 338
                    self.match(pddlParser.T__0)
                    self.state = 339
                    self.match(pddlParser.T__2)
                    pass

                elif la_ == 2:
                    self.state = 340
                    self.precondition()
                    pass




            self.state = 351
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==pddlParser.T__16:
                self.state = 345
                self.match(pddlParser.T__16)
                self.state = 349
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,28,self._ctx)
                if la_ == 1:
                    self.state = 346
                    self.match(pddlParser.T__0)
                    self.state = 347
                    self.match(pddlParser.T__2)
                    pass

                elif la_ == 2:
                    self.state = 348
                    self.effect()
                    pass




        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class PreconditionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def goalDesc(self):
            return self.getTypedRuleContext(pddlParser.GoalDescContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_precondition

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrecondition" ):
                listener.enterPrecondition(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrecondition" ):
                listener.exitPrecondition(self)




    def precondition(self):

        localctx = pddlParser.PreconditionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_precondition)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 353
            self.goalDesc()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class GoalDescContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def atomicTermFormula(self):
            return self.getTypedRuleContext(pddlParser.AtomicTermFormulaContext,0)


        def goalDesc(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.GoalDescContext)
            else:
                return self.getTypedRuleContext(pddlParser.GoalDescContext,i)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def fComp(self):
            return self.getTypedRuleContext(pddlParser.FCompContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_goalDesc

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGoalDesc" ):
                listener.enterGoalDesc(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGoalDesc" ):
                listener.exitGoalDesc(self)




    def goalDesc(self):

        localctx = pddlParser.GoalDescContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_goalDesc)
        self._la = 0 # Token type
        try:
            self.state = 402
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,32,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 355
                self.atomicTermFormula()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 356
                self.match(pddlParser.T__0)
                self.state = 357
                self.match(pddlParser.T__17)
                self.state = 361
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 358
                    self.goalDesc()
                    self.state = 363
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 364
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 365
                self.match(pddlParser.T__0)
                self.state = 366
                self.match(pddlParser.T__18)
                self.state = 370
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 367
                    self.goalDesc()
                    self.state = 372
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 373
                self.match(pddlParser.T__2)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 374
                self.match(pddlParser.T__0)
                self.state = 375
                self.match(pddlParser.T__19)
                self.state = 376
                self.goalDesc()
                self.state = 377
                self.match(pddlParser.T__2)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 379
                self.match(pddlParser.T__0)
                self.state = 380
                self.match(pddlParser.T__20)
                self.state = 381
                self.goalDesc()
                self.state = 382
                self.goalDesc()
                self.state = 383
                self.match(pddlParser.T__2)
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 385
                self.match(pddlParser.T__0)
                self.state = 386
                self.match(pddlParser.T__21)
                self.state = 387
                self.match(pddlParser.T__0)
                self.state = 388
                self.typedVariableList()
                self.state = 389
                self.match(pddlParser.T__2)
                self.state = 390
                self.goalDesc()
                self.state = 391
                self.match(pddlParser.T__2)
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 393
                self.match(pddlParser.T__0)
                self.state = 394
                self.match(pddlParser.T__22)
                self.state = 395
                self.match(pddlParser.T__0)
                self.state = 396
                self.typedVariableList()
                self.state = 397
                self.match(pddlParser.T__2)
                self.state = 398
                self.goalDesc()
                self.state = 399
                self.match(pddlParser.T__2)
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 401
                self.fComp()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FCompContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def binaryComp(self):
            return self.getTypedRuleContext(pddlParser.BinaryCompContext,0)


        def fExp(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.FExpContext)
            else:
                return self.getTypedRuleContext(pddlParser.FExpContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_fComp

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFComp" ):
                listener.enterFComp(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFComp" ):
                listener.exitFComp(self)




    def fComp(self):

        localctx = pddlParser.FCompContext(self, self._ctx, self.state)
        self.enterRule(localctx, 54, self.RULE_fComp)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 404
            self.match(pddlParser.T__0)
            self.state = 405
            self.binaryComp()
            self.state = 406
            self.fExp()
            self.state = 407
            self.fExp()
            self.state = 408
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class AtomicTermFormulaContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def predicate(self):
            return self.getTypedRuleContext(pddlParser.PredicateContext,0)


        def term(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.TermContext)
            else:
                return self.getTypedRuleContext(pddlParser.TermContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_atomicTermFormula

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAtomicTermFormula" ):
                listener.enterAtomicTermFormula(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAtomicTermFormula" ):
                listener.exitAtomicTermFormula(self)




    def atomicTermFormula(self):

        localctx = pddlParser.AtomicTermFormulaContext(self, self._ctx, self.state)
        self.enterRule(localctx, 56, self.RULE_atomicTermFormula)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 410
            self.match(pddlParser.T__0)
            self.state = 411
            self.predicate()
            self.state = 415
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)) | (1 << (pddlParser.VARIABLE - 28)))) != 0):
                self.state = 412
                self.term()
                self.state = 417
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 418
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TermContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def VARIABLE(self):
            return self.getToken(pddlParser.VARIABLE, 0)

        def getRuleIndex(self):
            return pddlParser.RULE_term

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTerm" ):
                listener.enterTerm(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTerm" ):
                listener.exitTerm(self)




    def term(self):

        localctx = pddlParser.TermContext(self, self._ctx, self.state)
        self.enterRule(localctx, 58, self.RULE_term)
        try:
            self.state = 422
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [pddlParser.T__27, pddlParser.T__28, pddlParser.NAME]:
                self.enterOuterAlt(localctx, 1)
                self.state = 420
                self.name()
                pass
            elif token in [pddlParser.VARIABLE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 421
                self.match(pddlParser.VARIABLE)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DurativeActionDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def actionSymbol(self):
            return self.getTypedRuleContext(pddlParser.ActionSymbolContext,0)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def daDefBody(self):
            return self.getTypedRuleContext(pddlParser.DaDefBodyContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_durativeActionDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDurativeActionDef" ):
                listener.enterDurativeActionDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDurativeActionDef" ):
                listener.exitDurativeActionDef(self)




    def durativeActionDef(self):

        localctx = pddlParser.DurativeActionDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 60, self.RULE_durativeActionDef)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 424
            self.match(pddlParser.T__0)
            self.state = 425
            self.match(pddlParser.T__23)
            self.state = 426
            self.actionSymbol()
            self.state = 427
            self.match(pddlParser.T__14)
            self.state = 428
            self.match(pddlParser.T__0)
            self.state = 429
            self.typedVariableList()
            self.state = 430
            self.match(pddlParser.T__2)
            self.state = 431
            self.daDefBody()
            self.state = 432
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DaDefBodyContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def durationConstraint(self):
            return self.getTypedRuleContext(pddlParser.DurationConstraintContext,0)


        def daGD(self):
            return self.getTypedRuleContext(pddlParser.DaGDContext,0)


        def daEffect(self):
            return self.getTypedRuleContext(pddlParser.DaEffectContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_daDefBody

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDaDefBody" ):
                listener.enterDaDefBody(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDaDefBody" ):
                listener.exitDaDefBody(self)




    def daDefBody(self):

        localctx = pddlParser.DaDefBodyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 62, self.RULE_daDefBody)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 434
            self.match(pddlParser.T__24)
            self.state = 435
            self.durationConstraint()
            self.state = 436
            self.match(pddlParser.T__25)
            self.state = 440
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,35,self._ctx)
            if la_ == 1:
                self.state = 437
                self.match(pddlParser.T__0)
                self.state = 438
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.state = 439
                self.daGD()
                pass


            self.state = 442
            self.match(pddlParser.T__16)
            self.state = 446
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,36,self._ctx)
            if la_ == 1:
                self.state = 443
                self.match(pddlParser.T__0)
                self.state = 444
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.state = 445
                self.daEffect()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DaGDContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def prefTimedGD(self):
            return self.getTypedRuleContext(pddlParser.PrefTimedGDContext,0)


        def daGD(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.DaGDContext)
            else:
                return self.getTypedRuleContext(pddlParser.DaGDContext,i)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_daGD

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDaGD" ):
                listener.enterDaGD(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDaGD" ):
                listener.exitDaGD(self)




    def daGD(self):

        localctx = pddlParser.DaGDContext(self, self._ctx, self.state)
        self.enterRule(localctx, 64, self.RULE_daGD)
        self._la = 0 # Token type
        try:
            self.state = 466
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,38,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 448
                self.prefTimedGD()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 449
                self.match(pddlParser.T__0)
                self.state = 450
                self.match(pddlParser.T__17)
                self.state = 454
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 451
                    self.daGD()
                    self.state = 456
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 457
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 458
                self.match(pddlParser.T__0)
                self.state = 459
                self.match(pddlParser.T__22)
                self.state = 460
                self.match(pddlParser.T__0)
                self.state = 461
                self.typedVariableList()
                self.state = 462
                self.match(pddlParser.T__2)
                self.state = 463
                self.daGD()
                self.state = 464
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class PrefTimedGDContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def timedGD(self):
            return self.getTypedRuleContext(pddlParser.TimedGDContext,0)


        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_prefTimedGD

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrefTimedGD" ):
                listener.enterPrefTimedGD(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrefTimedGD" ):
                listener.exitPrefTimedGD(self)




    def prefTimedGD(self):

        localctx = pddlParser.PrefTimedGDContext(self, self._ctx, self.state)
        self.enterRule(localctx, 66, self.RULE_prefTimedGD)
        self._la = 0 # Token type
        try:
            self.state = 477
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,40,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 468
                self.timedGD()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 469
                self.match(pddlParser.T__0)
                self.state = 470
                self.match(pddlParser.T__26)
                self.state = 472
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0):
                    self.state = 471
                    self.name()


                self.state = 474
                self.timedGD()
                self.state = 475
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TimedGDContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def timeSpecifier(self):
            return self.getTypedRuleContext(pddlParser.TimeSpecifierContext,0)


        def goalDesc(self):
            return self.getTypedRuleContext(pddlParser.GoalDescContext,0)


        def interval(self):
            return self.getTypedRuleContext(pddlParser.IntervalContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_timedGD

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTimedGD" ):
                listener.enterTimedGD(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTimedGD" ):
                listener.exitTimedGD(self)




    def timedGD(self):

        localctx = pddlParser.TimedGDContext(self, self._ctx, self.state)
        self.enterRule(localctx, 68, self.RULE_timedGD)
        try:
            self.state = 491
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,41,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 479
                self.match(pddlParser.T__0)
                self.state = 480
                self.match(pddlParser.T__27)
                self.state = 481
                self.timeSpecifier()
                self.state = 482
                self.goalDesc()
                self.state = 483
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 485
                self.match(pddlParser.T__0)
                self.state = 486
                self.match(pddlParser.T__28)
                self.state = 487
                self.interval()
                self.state = 488
                self.goalDesc()
                self.state = 489
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TimeSpecifierContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_timeSpecifier

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTimeSpecifier" ):
                listener.enterTimeSpecifier(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTimeSpecifier" ):
                listener.exitTimeSpecifier(self)




    def timeSpecifier(self):

        localctx = pddlParser.TimeSpecifierContext(self, self._ctx, self.state)
        self.enterRule(localctx, 70, self.RULE_timeSpecifier)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 493
            _la = self._input.LA(1)
            if not(_la==pddlParser.T__29 or _la==pddlParser.T__30):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class IntervalContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_interval

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInterval" ):
                listener.enterInterval(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInterval" ):
                listener.exitInterval(self)




    def interval(self):

        localctx = pddlParser.IntervalContext(self, self._ctx, self.state)
        self.enterRule(localctx, 72, self.RULE_interval)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 495
            self.match(pddlParser.T__31)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DerivedDefContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def goalDesc(self):
            return self.getTypedRuleContext(pddlParser.GoalDescContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_derivedDef

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDerivedDef" ):
                listener.enterDerivedDef(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDerivedDef" ):
                listener.exitDerivedDef(self)




    def derivedDef(self):

        localctx = pddlParser.DerivedDefContext(self, self._ctx, self.state)
        self.enterRule(localctx, 74, self.RULE_derivedDef)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 497
            self.match(pddlParser.T__0)
            self.state = 498
            self.match(pddlParser.T__32)
            self.state = 499
            self.typedVariableList()
            self.state = 500
            self.goalDesc()
            self.state = 501
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FExpContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NUMBER(self):
            return self.getToken(pddlParser.NUMBER, 0)

        def binaryOp(self):
            return self.getTypedRuleContext(pddlParser.BinaryOpContext,0)


        def fExp(self):
            return self.getTypedRuleContext(pddlParser.FExpContext,0)


        def fExp2(self):
            return self.getTypedRuleContext(pddlParser.FExp2Context,0)


        def fHead(self):
            return self.getTypedRuleContext(pddlParser.FHeadContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_fExp

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFExp" ):
                listener.enterFExp(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFExp" ):
                listener.exitFExp(self)




    def fExp(self):

        localctx = pddlParser.FExpContext(self, self._ctx, self.state)
        self.enterRule(localctx, 76, self.RULE_fExp)
        try:
            self.state = 516
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,42,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 503
                self.match(pddlParser.NUMBER)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 504
                self.match(pddlParser.T__0)
                self.state = 505
                self.binaryOp()
                self.state = 506
                self.fExp()
                self.state = 507
                self.fExp2()
                self.state = 508
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 510
                self.match(pddlParser.T__0)
                self.state = 511
                self.match(pddlParser.T__6)
                self.state = 512
                self.fExp()
                self.state = 513
                self.match(pddlParser.T__2)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 515
                self.fHead()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FExp2Context(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def fExp(self):
            return self.getTypedRuleContext(pddlParser.FExpContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_fExp2

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFExp2" ):
                listener.enterFExp2(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFExp2" ):
                listener.exitFExp2(self)




    def fExp2(self):

        localctx = pddlParser.FExp2Context(self, self._ctx, self.state)
        self.enterRule(localctx, 78, self.RULE_fExp2)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 518
            self.fExp()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FHeadContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def functionSymbol(self):
            return self.getTypedRuleContext(pddlParser.FunctionSymbolContext,0)


        def term(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.TermContext)
            else:
                return self.getTypedRuleContext(pddlParser.TermContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_fHead

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFHead" ):
                listener.enterFHead(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFHead" ):
                listener.exitFHead(self)




    def fHead(self):

        localctx = pddlParser.FHeadContext(self, self._ctx, self.state)
        self.enterRule(localctx, 80, self.RULE_fHead)
        self._la = 0 # Token type
        try:
            self.state = 531
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [pddlParser.T__0]:
                self.enterOuterAlt(localctx, 1)
                self.state = 520
                self.match(pddlParser.T__0)
                self.state = 521
                self.functionSymbol()
                self.state = 525
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)) | (1 << (pddlParser.VARIABLE - 28)))) != 0):
                    self.state = 522
                    self.term()
                    self.state = 527
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 528
                self.match(pddlParser.T__2)
                pass
            elif token in [pddlParser.T__27, pddlParser.T__28, pddlParser.NAME]:
                self.enterOuterAlt(localctx, 2)
                self.state = 530
                self.functionSymbol()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class EffectContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def cEffect(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.CEffectContext)
            else:
                return self.getTypedRuleContext(pddlParser.CEffectContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_effect

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterEffect" ):
                listener.enterEffect(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitEffect" ):
                listener.exitEffect(self)




    def effect(self):

        localctx = pddlParser.EffectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 82, self.RULE_effect)
        self._la = 0 # Token type
        try:
            self.state = 543
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,46,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 533
                self.match(pddlParser.T__0)
                self.state = 534
                self.match(pddlParser.T__17)
                self.state = 538
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 535
                    self.cEffect()
                    self.state = 540
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 541
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 542
                self.cEffect()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class CEffectContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def effect(self):
            return self.getTypedRuleContext(pddlParser.EffectContext,0)


        def goalDesc(self):
            return self.getTypedRuleContext(pddlParser.GoalDescContext,0)


        def condEffect(self):
            return self.getTypedRuleContext(pddlParser.CondEffectContext,0)


        def pEffect(self):
            return self.getTypedRuleContext(pddlParser.PEffectContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_cEffect

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCEffect" ):
                listener.enterCEffect(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCEffect" ):
                listener.exitCEffect(self)




    def cEffect(self):

        localctx = pddlParser.CEffectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 84, self.RULE_cEffect)
        try:
            self.state = 560
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,47,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 545
                self.match(pddlParser.T__0)
                self.state = 546
                self.match(pddlParser.T__22)
                self.state = 547
                self.match(pddlParser.T__0)
                self.state = 548
                self.typedVariableList()
                self.state = 549
                self.match(pddlParser.T__2)
                self.state = 550
                self.effect()
                self.state = 551
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 553
                self.match(pddlParser.T__0)
                self.state = 554
                self.match(pddlParser.T__33)
                self.state = 555
                self.goalDesc()
                self.state = 556
                self.condEffect()
                self.state = 557
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 559
                self.pEffect()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class PEffectContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def assignOp(self):
            return self.getTypedRuleContext(pddlParser.AssignOpContext,0)


        def fHead(self):
            return self.getTypedRuleContext(pddlParser.FHeadContext,0)


        def fExp(self):
            return self.getTypedRuleContext(pddlParser.FExpContext,0)


        def atomicTermFormula(self):
            return self.getTypedRuleContext(pddlParser.AtomicTermFormulaContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_pEffect

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPEffect" ):
                listener.enterPEffect(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPEffect" ):
                listener.exitPEffect(self)




    def pEffect(self):

        localctx = pddlParser.PEffectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 86, self.RULE_pEffect)
        try:
            self.state = 574
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,48,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 562
                self.match(pddlParser.T__0)
                self.state = 563
                self.assignOp()
                self.state = 564
                self.fHead()
                self.state = 565
                self.fExp()
                self.state = 566
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 568
                self.match(pddlParser.T__0)
                self.state = 569
                self.match(pddlParser.T__19)
                self.state = 570
                self.atomicTermFormula()
                self.state = 571
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 573
                self.atomicTermFormula()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class CondEffectContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pEffect(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.PEffectContext)
            else:
                return self.getTypedRuleContext(pddlParser.PEffectContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_condEffect

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCondEffect" ):
                listener.enterCondEffect(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCondEffect" ):
                listener.exitCondEffect(self)




    def condEffect(self):

        localctx = pddlParser.CondEffectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 88, self.RULE_condEffect)
        self._la = 0 # Token type
        try:
            self.state = 586
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,50,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 576
                self.match(pddlParser.T__0)
                self.state = 577
                self.match(pddlParser.T__17)
                self.state = 581
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 578
                    self.pEffect()
                    self.state = 583
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 584
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 585
                self.pEffect()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class BinaryOpContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_binaryOp

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBinaryOp" ):
                listener.enterBinaryOp(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBinaryOp" ):
                listener.exitBinaryOp(self)




    def binaryOp(self):

        localctx = pddlParser.BinaryOpContext(self, self._ctx, self.state)
        self.enterRule(localctx, 90, self.RULE_binaryOp)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 588
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << pddlParser.T__6) | (1 << pddlParser.T__34) | (1 << pddlParser.T__35) | (1 << pddlParser.T__36))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class BinaryCompContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_binaryComp

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBinaryComp" ):
                listener.enterBinaryComp(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBinaryComp" ):
                listener.exitBinaryComp(self)




    def binaryComp(self):

        localctx = pddlParser.BinaryCompContext(self, self._ctx, self.state)
        self.enterRule(localctx, 92, self.RULE_binaryComp)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 590
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << pddlParser.T__37) | (1 << pddlParser.T__38) | (1 << pddlParser.T__39) | (1 << pddlParser.T__40) | (1 << pddlParser.T__41))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class AssignOpContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_assignOp

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAssignOp" ):
                listener.enterAssignOp(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAssignOp" ):
                listener.exitAssignOp(self)




    def assignOp(self):

        localctx = pddlParser.AssignOpContext(self, self._ctx, self.state)
        self.enterRule(localctx, 94, self.RULE_assignOp)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 592
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << pddlParser.T__42) | (1 << pddlParser.T__43) | (1 << pddlParser.T__44) | (1 << pddlParser.T__45) | (1 << pddlParser.T__46))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DurationConstraintContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def simpleDurationConstraint(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.SimpleDurationConstraintContext)
            else:
                return self.getTypedRuleContext(pddlParser.SimpleDurationConstraintContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_durationConstraint

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDurationConstraint" ):
                listener.enterDurationConstraint(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDurationConstraint" ):
                listener.exitDurationConstraint(self)




    def durationConstraint(self):

        localctx = pddlParser.DurationConstraintContext(self, self._ctx, self.state)
        self.enterRule(localctx, 96, self.RULE_durationConstraint)
        self._la = 0 # Token type
        try:
            self.state = 606
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,52,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 594
                self.match(pddlParser.T__0)
                self.state = 595
                self.match(pddlParser.T__17)
                self.state = 597 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 596
                    self.simpleDurationConstraint()
                    self.state = 599 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (_la==pddlParser.T__0):
                        break

                self.state = 601
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 603
                self.match(pddlParser.T__0)
                self.state = 604
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 605
                self.simpleDurationConstraint()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class SimpleDurationConstraintContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def durOp(self):
            return self.getTypedRuleContext(pddlParser.DurOpContext,0)


        def durValue(self):
            return self.getTypedRuleContext(pddlParser.DurValueContext,0)


        def timeSpecifier(self):
            return self.getTypedRuleContext(pddlParser.TimeSpecifierContext,0)


        def simpleDurationConstraint(self):
            return self.getTypedRuleContext(pddlParser.SimpleDurationConstraintContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_simpleDurationConstraint

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSimpleDurationConstraint" ):
                listener.enterSimpleDurationConstraint(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSimpleDurationConstraint" ):
                listener.exitSimpleDurationConstraint(self)




    def simpleDurationConstraint(self):

        localctx = pddlParser.SimpleDurationConstraintContext(self, self._ctx, self.state)
        self.enterRule(localctx, 98, self.RULE_simpleDurationConstraint)
        try:
            self.state = 620
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,53,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 608
                self.match(pddlParser.T__0)
                self.state = 609
                self.durOp()
                self.state = 610
                self.match(pddlParser.T__47)
                self.state = 611
                self.durValue()
                self.state = 612
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 614
                self.match(pddlParser.T__0)
                self.state = 615
                self.match(pddlParser.T__27)
                self.state = 616
                self.timeSpecifier()
                self.state = 617
                self.simpleDurationConstraint()
                self.state = 618
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DurOpContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_durOp

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDurOp" ):
                listener.enterDurOp(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDurOp" ):
                listener.exitDurOp(self)




    def durOp(self):

        localctx = pddlParser.DurOpContext(self, self._ctx, self.state)
        self.enterRule(localctx, 100, self.RULE_durOp)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 622
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << pddlParser.T__39) | (1 << pddlParser.T__40) | (1 << pddlParser.T__41))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DurValueContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NUMBER(self):
            return self.getToken(pddlParser.NUMBER, 0)

        def fExp(self):
            return self.getTypedRuleContext(pddlParser.FExpContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_durValue

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDurValue" ):
                listener.enterDurValue(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDurValue" ):
                listener.exitDurValue(self)




    def durValue(self):

        localctx = pddlParser.DurValueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 102, self.RULE_durValue)
        try:
            self.state = 626
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,54,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 624
                self.match(pddlParser.NUMBER)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 625
                self.fExp()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class DaEffectContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def daEffect(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.DaEffectContext)
            else:
                return self.getTypedRuleContext(pddlParser.DaEffectContext,i)


        def timedEffect(self):
            return self.getTypedRuleContext(pddlParser.TimedEffectContext,0)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def daGD(self):
            return self.getTypedRuleContext(pddlParser.DaGDContext,0)


        def assignOp(self):
            return self.getTypedRuleContext(pddlParser.AssignOpContext,0)


        def fHead(self):
            return self.getTypedRuleContext(pddlParser.FHeadContext,0)


        def fExpDA(self):
            return self.getTypedRuleContext(pddlParser.FExpDAContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_daEffect

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDaEffect" ):
                listener.enterDaEffect(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDaEffect" ):
                listener.exitDaEffect(self)




    def daEffect(self):

        localctx = pddlParser.DaEffectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 104, self.RULE_daEffect)
        self._la = 0 # Token type
        try:
            self.state = 658
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,56,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 628
                self.match(pddlParser.T__0)
                self.state = 629
                self.match(pddlParser.T__17)
                self.state = 633
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 630
                    self.daEffect()
                    self.state = 635
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 636
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 637
                self.timedEffect()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 638
                self.match(pddlParser.T__0)
                self.state = 639
                self.match(pddlParser.T__22)
                self.state = 640
                self.match(pddlParser.T__0)
                self.state = 641
                self.typedVariableList()
                self.state = 642
                self.match(pddlParser.T__2)
                self.state = 643
                self.daEffect()
                self.state = 644
                self.match(pddlParser.T__2)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 646
                self.match(pddlParser.T__0)
                self.state = 647
                self.match(pddlParser.T__33)
                self.state = 648
                self.daGD()
                self.state = 649
                self.timedEffect()
                self.state = 650
                self.match(pddlParser.T__2)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 652
                self.match(pddlParser.T__0)
                self.state = 653
                self.assignOp()
                self.state = 654
                self.fHead()
                self.state = 655
                self.fExpDA()
                self.state = 656
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TimedEffectContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def timeSpecifier(self):
            return self.getTypedRuleContext(pddlParser.TimeSpecifierContext,0)


        def cEffect(self):
            return self.getTypedRuleContext(pddlParser.CEffectContext,0)


        def fAssignDA(self):
            return self.getTypedRuleContext(pddlParser.FAssignDAContext,0)


        def assignOpT(self):
            return self.getTypedRuleContext(pddlParser.AssignOpTContext,0)


        def fHead(self):
            return self.getTypedRuleContext(pddlParser.FHeadContext,0)


        def fExp(self):
            return self.getTypedRuleContext(pddlParser.FExpContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_timedEffect

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTimedEffect" ):
                listener.enterTimedEffect(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTimedEffect" ):
                listener.exitTimedEffect(self)




    def timedEffect(self):

        localctx = pddlParser.TimedEffectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 106, self.RULE_timedEffect)
        try:
            self.state = 678
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,57,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 660
                self.match(pddlParser.T__0)
                self.state = 661
                self.match(pddlParser.T__27)
                self.state = 662
                self.timeSpecifier()
                self.state = 663
                self.cEffect()
                self.state = 664
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 666
                self.match(pddlParser.T__0)
                self.state = 667
                self.match(pddlParser.T__27)
                self.state = 668
                self.timeSpecifier()
                self.state = 669
                self.fAssignDA()
                self.state = 670
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 672
                self.match(pddlParser.T__0)
                self.state = 673
                self.assignOpT()
                self.state = 674
                self.fHead()
                self.state = 675
                self.fExp()
                self.state = 676
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FAssignDAContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def assignOp(self):
            return self.getTypedRuleContext(pddlParser.AssignOpContext,0)


        def fHead(self):
            return self.getTypedRuleContext(pddlParser.FHeadContext,0)


        def fExpDA(self):
            return self.getTypedRuleContext(pddlParser.FExpDAContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_fAssignDA

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFAssignDA" ):
                listener.enterFAssignDA(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFAssignDA" ):
                listener.exitFAssignDA(self)




    def fAssignDA(self):

        localctx = pddlParser.FAssignDAContext(self, self._ctx, self.state)
        self.enterRule(localctx, 108, self.RULE_fAssignDA)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 680
            self.match(pddlParser.T__0)
            self.state = 681
            self.assignOp()
            self.state = 682
            self.fHead()
            self.state = 683
            self.fExpDA()
            self.state = 684
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class FExpDAContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def binaryOp(self):
            return self.getTypedRuleContext(pddlParser.BinaryOpContext,0)


        def fExpDA(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.FExpDAContext)
            else:
                return self.getTypedRuleContext(pddlParser.FExpDAContext,i)


        def fExp(self):
            return self.getTypedRuleContext(pddlParser.FExpContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_fExpDA

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFExpDA" ):
                listener.enterFExpDA(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFExpDA" ):
                listener.exitFExpDA(self)




    def fExpDA(self):

        localctx = pddlParser.FExpDAContext(self, self._ctx, self.state)
        self.enterRule(localctx, 110, self.RULE_fExpDA)
        try:
            self.state = 699
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,59,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 686
                self.match(pddlParser.T__0)
                self.state = 693
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,58,self._ctx)
                if la_ == 1:
                    self.state = 687
                    self.binaryOp()
                    self.state = 688
                    self.fExpDA()
                    self.state = 689
                    self.fExpDA()
                    pass

                elif la_ == 2:
                    self.state = 691
                    self.match(pddlParser.T__6)
                    self.state = 692
                    self.fExpDA()
                    pass


                self.state = 695
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 697
                self.match(pddlParser.T__47)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 698
                self.fExp()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class AssignOpTContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_assignOpT

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAssignOpT" ):
                listener.enterAssignOpT(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAssignOpT" ):
                listener.exitAssignOpT(self)




    def assignOpT(self):

        localctx = pddlParser.AssignOpTContext(self, self._ctx, self.state)
        self.enterRule(localctx, 112, self.RULE_assignOpT)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 701
            _la = self._input.LA(1)
            if not(_la==pddlParser.T__45 or _la==pddlParser.T__46):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ProblemContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def problemDecl(self):
            return self.getTypedRuleContext(pddlParser.ProblemDeclContext,0)


        def problemDomain(self):
            return self.getTypedRuleContext(pddlParser.ProblemDomainContext,0)


        def init(self):
            return self.getTypedRuleContext(pddlParser.InitContext,0)


        def goal(self):
            return self.getTypedRuleContext(pddlParser.GoalContext,0)


        def requireDef(self):
            return self.getTypedRuleContext(pddlParser.RequireDefContext,0)


        def objectDecl(self):
            return self.getTypedRuleContext(pddlParser.ObjectDeclContext,0)


        def probConstraints(self):
            return self.getTypedRuleContext(pddlParser.ProbConstraintsContext,0)


        def metricSpec(self):
            return self.getTypedRuleContext(pddlParser.MetricSpecContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_problem

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProblem" ):
                listener.enterProblem(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProblem" ):
                listener.exitProblem(self)




    def problem(self):

        localctx = pddlParser.ProblemContext(self, self._ctx, self.state)
        self.enterRule(localctx, 114, self.RULE_problem)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 703
            self.match(pddlParser.T__0)
            self.state = 704
            self.match(pddlParser.T__1)
            self.state = 705
            self.problemDecl()
            self.state = 706
            self.problemDomain()
            self.state = 708
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,60,self._ctx)
            if la_ == 1:
                self.state = 707
                self.requireDef()


            self.state = 711
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,61,self._ctx)
            if la_ == 1:
                self.state = 710
                self.objectDecl()


            self.state = 713
            self.init()
            self.state = 714
            self.goal()
            self.state = 716
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,62,self._ctx)
            if la_ == 1:
                self.state = 715
                self.probConstraints()


            self.state = 719
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==pddlParser.T__0:
                self.state = 718
                self.metricSpec()


            self.state = 721
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ProblemDeclContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_problemDecl

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProblemDecl" ):
                listener.enterProblemDecl(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProblemDecl" ):
                listener.exitProblemDecl(self)




    def problemDecl(self):

        localctx = pddlParser.ProblemDeclContext(self, self._ctx, self.state)
        self.enterRule(localctx, 116, self.RULE_problemDecl)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 723
            self.match(pddlParser.T__0)
            self.state = 724
            self.match(pddlParser.T__48)
            self.state = 725
            self.name()
            self.state = 726
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ProblemDomainContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_problemDomain

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProblemDomain" ):
                listener.enterProblemDomain(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProblemDomain" ):
                listener.exitProblemDomain(self)




    def problemDomain(self):

        localctx = pddlParser.ProblemDomainContext(self, self._ctx, self.state)
        self.enterRule(localctx, 118, self.RULE_problemDomain)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 728
            self.match(pddlParser.T__0)
            self.state = 729
            self.match(pddlParser.T__49)
            self.state = 730
            self.name()
            self.state = 731
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ObjectDeclContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def typedNameList(self):
            return self.getTypedRuleContext(pddlParser.TypedNameListContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_objectDecl

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterObjectDecl" ):
                listener.enterObjectDecl(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitObjectDecl" ):
                listener.exitObjectDecl(self)




    def objectDecl(self):

        localctx = pddlParser.ObjectDeclContext(self, self._ctx, self.state)
        self.enterRule(localctx, 120, self.RULE_objectDecl)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 733
            self.match(pddlParser.T__0)
            self.state = 734
            self.match(pddlParser.T__50)
            self.state = 735
            self.typedNameList()
            self.state = 736
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class InitContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def initEl(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.InitElContext)
            else:
                return self.getTypedRuleContext(pddlParser.InitElContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_init

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInit" ):
                listener.enterInit(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInit" ):
                listener.exitInit(self)




    def init(self):

        localctx = pddlParser.InitContext(self, self._ctx, self.state)
        self.enterRule(localctx, 122, self.RULE_init)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 738
            self.match(pddlParser.T__0)
            self.state = 739
            self.match(pddlParser.T__51)
            self.state = 743
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==pddlParser.T__0:
                self.state = 740
                self.initEl()
                self.state = 745
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 746
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class InitElContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def nameLiteral(self):
            return self.getTypedRuleContext(pddlParser.NameLiteralContext,0)


        def fHead(self):
            return self.getTypedRuleContext(pddlParser.FHeadContext,0)


        def NUMBER(self):
            return self.getToken(pddlParser.NUMBER, 0)

        def getRuleIndex(self):
            return pddlParser.RULE_initEl

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInitEl" ):
                listener.enterInitEl(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInitEl" ):
                listener.exitInitEl(self)




    def initEl(self):

        localctx = pddlParser.InitElContext(self, self._ctx, self.state)
        self.enterRule(localctx, 124, self.RULE_initEl)
        try:
            self.state = 761
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,65,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 748
                self.nameLiteral()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 749
                self.match(pddlParser.T__0)
                self.state = 750
                self.match(pddlParser.T__39)
                self.state = 751
                self.fHead()
                self.state = 752
                self.match(pddlParser.NUMBER)
                self.state = 753
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 755
                self.match(pddlParser.T__0)
                self.state = 756
                self.match(pddlParser.T__27)
                self.state = 757
                self.match(pddlParser.NUMBER)
                self.state = 758
                self.nameLiteral()
                self.state = 759
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class NameLiteralContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def atomicNameFormula(self):
            return self.getTypedRuleContext(pddlParser.AtomicNameFormulaContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_nameLiteral

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNameLiteral" ):
                listener.enterNameLiteral(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNameLiteral" ):
                listener.exitNameLiteral(self)




    def nameLiteral(self):

        localctx = pddlParser.NameLiteralContext(self, self._ctx, self.state)
        self.enterRule(localctx, 126, self.RULE_nameLiteral)
        try:
            self.state = 769
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,66,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 763
                self.atomicNameFormula()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 764
                self.match(pddlParser.T__0)
                self.state = 765
                self.match(pddlParser.T__19)
                self.state = 766
                self.atomicNameFormula()
                self.state = 767
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class AtomicNameFormulaContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def predicate(self):
            return self.getTypedRuleContext(pddlParser.PredicateContext,0)


        def name(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.NameContext)
            else:
                return self.getTypedRuleContext(pddlParser.NameContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_atomicNameFormula

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAtomicNameFormula" ):
                listener.enterAtomicNameFormula(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAtomicNameFormula" ):
                listener.exitAtomicNameFormula(self)




    def atomicNameFormula(self):

        localctx = pddlParser.AtomicNameFormulaContext(self, self._ctx, self.state)
        self.enterRule(localctx, 128, self.RULE_atomicNameFormula)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 771
            self.match(pddlParser.T__0)
            self.state = 772
            self.predicate()
            self.state = 776
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0):
                self.state = 773
                self.name()
                self.state = 778
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 779
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class GoalContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def goalDesc(self):
            return self.getTypedRuleContext(pddlParser.GoalDescContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_goal

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGoal" ):
                listener.enterGoal(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGoal" ):
                listener.exitGoal(self)




    def goal(self):

        localctx = pddlParser.GoalContext(self, self._ctx, self.state)
        self.enterRule(localctx, 130, self.RULE_goal)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 781
            self.match(pddlParser.T__0)
            self.state = 782
            self.match(pddlParser.T__52)
            self.state = 783
            self.goalDesc()
            self.state = 784
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ProbConstraintsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def prefConGD(self):
            return self.getTypedRuleContext(pddlParser.PrefConGDContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_probConstraints

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProbConstraints" ):
                listener.enterProbConstraints(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProbConstraints" ):
                listener.exitProbConstraints(self)




    def probConstraints(self):

        localctx = pddlParser.ProbConstraintsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 132, self.RULE_probConstraints)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 786
            self.match(pddlParser.T__0)
            self.state = 787
            self.match(pddlParser.T__12)
            self.state = 788
            self.prefConGD()
            self.state = 789
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class PrefConGDContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def prefConGD(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.PrefConGDContext)
            else:
                return self.getTypedRuleContext(pddlParser.PrefConGDContext,i)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def conGD(self):
            return self.getTypedRuleContext(pddlParser.ConGDContext,0)


        def name(self):
            return self.getTypedRuleContext(pddlParser.NameContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_prefConGD

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrefConGD" ):
                listener.enterPrefConGD(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrefConGD" ):
                listener.exitPrefConGD(self)




    def prefConGD(self):

        localctx = pddlParser.PrefConGDContext(self, self._ctx, self.state)
        self.enterRule(localctx, 134, self.RULE_prefConGD)
        self._la = 0 # Token type
        try:
            self.state = 817
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,70,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 791
                self.match(pddlParser.T__0)
                self.state = 792
                self.match(pddlParser.T__17)
                self.state = 796
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 793
                    self.prefConGD()
                    self.state = 798
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 799
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 800
                self.match(pddlParser.T__0)
                self.state = 801
                self.match(pddlParser.T__22)
                self.state = 802
                self.match(pddlParser.T__0)
                self.state = 803
                self.typedVariableList()
                self.state = 804
                self.match(pddlParser.T__2)
                self.state = 805
                self.prefConGD()
                self.state = 806
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 808
                self.match(pddlParser.T__0)
                self.state = 809
                self.match(pddlParser.T__26)
                self.state = 811
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0):
                    self.state = 810
                    self.name()


                self.state = 813
                self.conGD()
                self.state = 814
                self.match(pddlParser.T__2)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 816
                self.conGD()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class MetricSpecContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def optimization(self):
            return self.getTypedRuleContext(pddlParser.OptimizationContext,0)


        def metricFExp(self):
            return self.getTypedRuleContext(pddlParser.MetricFExpContext,0)


        def getRuleIndex(self):
            return pddlParser.RULE_metricSpec

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMetricSpec" ):
                listener.enterMetricSpec(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMetricSpec" ):
                listener.exitMetricSpec(self)




    def metricSpec(self):

        localctx = pddlParser.MetricSpecContext(self, self._ctx, self.state)
        self.enterRule(localctx, 136, self.RULE_metricSpec)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 819
            self.match(pddlParser.T__0)
            self.state = 820
            self.match(pddlParser.T__53)
            self.state = 821
            self.optimization()
            self.state = 822
            self.metricFExp()
            self.state = 823
            self.match(pddlParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class OptimizationContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return pddlParser.RULE_optimization

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOptimization" ):
                listener.enterOptimization(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOptimization" ):
                listener.exitOptimization(self)




    def optimization(self):

        localctx = pddlParser.OptimizationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 138, self.RULE_optimization)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 825
            _la = self._input.LA(1)
            if not(_la==pddlParser.T__54 or _la==pddlParser.T__55):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class MetricFExpContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def binaryOp(self):
            return self.getTypedRuleContext(pddlParser.BinaryOpContext,0)


        def metricFExp(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.MetricFExpContext)
            else:
                return self.getTypedRuleContext(pddlParser.MetricFExpContext,i)


        def NUMBER(self):
            return self.getToken(pddlParser.NUMBER, 0)

        def functionSymbol(self):
            return self.getTypedRuleContext(pddlParser.FunctionSymbolContext,0)


        def name(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.NameContext)
            else:
                return self.getTypedRuleContext(pddlParser.NameContext,i)


        def getRuleIndex(self):
            return pddlParser.RULE_metricFExp

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMetricFExp" ):
                listener.enterMetricFExp(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMetricFExp" ):
                listener.exitMetricFExp(self)




    def metricFExp(self):

        localctx = pddlParser.MetricFExpContext(self, self._ctx, self.state)
        self.enterRule(localctx, 140, self.RULE_metricFExp)
        self._la = 0 # Token type
        try:
            self.state = 866
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,73,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 827
                self.match(pddlParser.T__0)
                self.state = 828
                self.binaryOp()
                self.state = 829
                self.metricFExp()
                self.state = 830
                self.metricFExp()
                self.state = 831
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 833
                self.match(pddlParser.T__0)
                self.state = 834
                _la = self._input.LA(1)
                if not(_la==pddlParser.T__34 or _la==pddlParser.T__36):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 835
                self.metricFExp()
                self.state = 837 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 836
                    self.metricFExp()
                    self.state = 839 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << pddlParser.T__0) | (1 << pddlParser.T__27) | (1 << pddlParser.T__28) | (1 << pddlParser.T__56))) != 0) or _la==pddlParser.NAME or _la==pddlParser.NUMBER):
                        break

                self.state = 841
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 843
                self.match(pddlParser.T__0)
                self.state = 844
                self.match(pddlParser.T__6)
                self.state = 845
                self.metricFExp()
                self.state = 846
                self.match(pddlParser.T__2)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 848
                self.match(pddlParser.NUMBER)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 849
                self.match(pddlParser.T__0)
                self.state = 850
                self.functionSymbol()
                self.state = 854
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while ((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0):
                    self.state = 851
                    self.name()
                    self.state = 856
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 857
                self.match(pddlParser.T__2)
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 859
                self.functionSymbol()
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 860
                self.match(pddlParser.T__56)
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 861
                self.match(pddlParser.T__0)
                self.state = 862
                self.match(pddlParser.T__57)
                self.state = 863
                self.name()
                self.state = 864
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ConGDContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def conGD(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.ConGDContext)
            else:
                return self.getTypedRuleContext(pddlParser.ConGDContext,i)


        def typedVariableList(self):
            return self.getTypedRuleContext(pddlParser.TypedVariableListContext,0)


        def goalDesc(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(pddlParser.GoalDescContext)
            else:
                return self.getTypedRuleContext(pddlParser.GoalDescContext,i)


        def NUMBER(self, i:int=None):
            if i is None:
                return self.getTokens(pddlParser.NUMBER)
            else:
                return self.getToken(pddlParser.NUMBER, i)

        def getRuleIndex(self):
            return pddlParser.RULE_conGD

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConGD" ):
                listener.enterConGD(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConGD" ):
                listener.exitConGD(self)




    def conGD(self):

        localctx = pddlParser.ConGDContext(self, self._ctx, self.state)
        self.enterRule(localctx, 142, self.RULE_conGD)
        self._la = 0 # Token type
        try:
            self.state = 944
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,75,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 868
                self.match(pddlParser.T__0)
                self.state = 869
                self.match(pddlParser.T__17)
                self.state = 873
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==pddlParser.T__0:
                    self.state = 870
                    self.conGD()
                    self.state = 875
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 876
                self.match(pddlParser.T__2)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 877
                self.match(pddlParser.T__0)
                self.state = 878
                self.match(pddlParser.T__22)
                self.state = 879
                self.match(pddlParser.T__0)
                self.state = 880
                self.typedVariableList()
                self.state = 881
                self.match(pddlParser.T__2)
                self.state = 882
                self.conGD()
                self.state = 883
                self.match(pddlParser.T__2)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 885
                self.match(pddlParser.T__0)
                self.state = 886
                self.match(pddlParser.T__27)
                self.state = 887
                self.match(pddlParser.T__30)
                self.state = 888
                self.goalDesc()
                self.state = 889
                self.match(pddlParser.T__2)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 891
                self.match(pddlParser.T__0)
                self.state = 892
                self.match(pddlParser.T__58)
                self.state = 893
                self.goalDesc()
                self.state = 894
                self.match(pddlParser.T__2)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 896
                self.match(pddlParser.T__0)
                self.state = 897
                self.match(pddlParser.T__59)
                self.state = 898
                self.goalDesc()
                self.state = 899
                self.match(pddlParser.T__2)
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 901
                self.match(pddlParser.T__0)
                self.state = 902
                self.match(pddlParser.T__60)
                self.state = 903
                self.match(pddlParser.NUMBER)
                self.state = 904
                self.goalDesc()
                self.state = 905
                self.match(pddlParser.T__2)
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 907
                self.match(pddlParser.T__0)
                self.state = 908
                self.match(pddlParser.T__61)
                self.state = 909
                self.goalDesc()
                self.state = 910
                self.match(pddlParser.T__2)
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 912
                self.match(pddlParser.T__0)
                self.state = 913
                self.match(pddlParser.T__62)
                self.state = 914
                self.goalDesc()
                self.state = 915
                self.goalDesc()
                self.state = 916
                self.match(pddlParser.T__2)
                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 918
                self.match(pddlParser.T__0)
                self.state = 919
                self.match(pddlParser.T__63)
                self.state = 920
                self.goalDesc()
                self.state = 921
                self.goalDesc()
                self.state = 922
                self.match(pddlParser.T__2)
                pass

            elif la_ == 10:
                self.enterOuterAlt(localctx, 10)
                self.state = 924
                self.match(pddlParser.T__0)
                self.state = 925
                self.match(pddlParser.T__64)
                self.state = 926
                self.match(pddlParser.NUMBER)
                self.state = 927
                self.goalDesc()
                self.state = 928
                self.goalDesc()
                self.state = 929
                self.match(pddlParser.T__2)
                pass

            elif la_ == 11:
                self.enterOuterAlt(localctx, 11)
                self.state = 931
                self.match(pddlParser.T__0)
                self.state = 932
                self.match(pddlParser.T__65)
                self.state = 933
                self.match(pddlParser.NUMBER)
                self.state = 934
                self.match(pddlParser.NUMBER)
                self.state = 935
                self.goalDesc()
                self.state = 936
                self.match(pddlParser.T__2)
                pass

            elif la_ == 12:
                self.enterOuterAlt(localctx, 12)
                self.state = 938
                self.match(pddlParser.T__0)
                self.state = 939
                self.match(pddlParser.T__66)
                self.state = 940
                self.match(pddlParser.NUMBER)
                self.state = 941
                self.goalDesc()
                self.state = 942
                self.match(pddlParser.T__2)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class NameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self):
            return self.getToken(pddlParser.NAME, 0)

        def getRuleIndex(self):
            return pddlParser.RULE_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterName" ):
                listener.enterName(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitName" ):
                listener.exitName(self)




    def name(self):

        localctx = pddlParser.NameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 144, self.RULE_name)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 946
            _la = self._input.LA(1)
            if not(((((_la - 28)) & ~0x3f) == 0 and ((1 << (_la - 28)) & ((1 << (pddlParser.T__27 - 28)) | (1 << (pddlParser.T__28 - 28)) | (1 << (pddlParser.NAME - 28)))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx





